from ..Part.PartBase import PartBase
from ..UtilityAndView.abaqusConstants import *


class RegionPartBase(PartBase):
    """The following commands operate on Part objects. For more information about the Part
    object, see Part object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import regionToolset
    """

    def clashSets(self, arg1: str, arg2: str):
        """This command prints a message describing the relationship between the contents of two
        sets. Possible outcomes are:
            - Both sets are the same.
            - Set 2 is a subset of set 1.
            - Set 2 is a superset of set 1.
            - Set 2 intersects set 1.
            - Set 2 touches set 1 (their boundaries intersect).
            - Set 2 and set 1 are disjoint.
        This command accepts only positional arguments and has no keywords.

        Parameters
        ----------
        arg1
            A Set or Surface object specifying set 1.
        arg2
            A Set or Surface object specifying set 2.
        """
        ...

    def markSetInternal(self, setName: str, internalSet: Boolean):
        """This command marks the given Set as internal or external.

        Parameters
        ----------
        setName
            A string specifying the Set name.
        internalSet
            A Boolean specifying whether the Set should be marked as internal.
        """
        ...

    def markSurfaceInternal(self, setName: str, internalSurface: Boolean):
        """This command marks the given Surface as internal or external.

        Parameters
        ----------
        setName
            A string specifying the Surface name.
        internalSurface
            A Boolean specifying whether the Surface should be marked as internal.
        """
        ...

    def isSetInternal(self, setName: str):
        """This command returns a flag indicating whether the Set is Internal.

        Parameters
        ----------
        setName
            A string specifying the Set name.
        """
        ...

    def isSurfaceInternal(self, surfaceName: str):
        """This command returns a flag indicating whether the Surface is Internal.

        Parameters
        ----------
        surfaceName
            A string specifying the Surface name.
        """
        ...

    def deleteSets(self, setNames: tuple):
        """This command deletes the given sets from the part.

        Parameters
        ----------
        setNames
            A sequence of Strings specifying the set names that will be deleted from the part.
        """
        ...

    def deleteSurfaces(self, surfaceNames: tuple):
        """This command deletes the given surfaces from the part.

        Parameters
        ----------
        surfaceNames
            A sequence of Strings specifying the surface names that will be deleted from the part.
        """
        ...



from ..UtilityAndView.abaqusConstants import *


class Amplitude:
    """The Amplitude object is the abstract base type for other Amplitude objects. The
    Amplitude object has no explicit constructor. The methods and members of the Amplitude
    object are common to all objects derived from the Amplitude.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import amplitude
            mdb.models[name].amplitudes[name]
            import odbAmplitude
            session.odbs[name].amplitudes[name]
    """

    #: A String specifying the repository key.
    name: str = ""

    #: A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP
    #: and TOTAL. The default value is STEP.
    timeSpan: SymbolicConstant = STEP



import typing

# from .ErrorIndicatorResult import ErrorIndicatorResult


# Prevent circular import
class ErrorIndicatorResult:
    ...


class RuleResult:
    """The RuleResult object contains result information corresponding to a RemeshingRule
    object for an adaptivity iteration.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import job
            mdb.adaptivityProcesses[name].iterations[i].ruleResults[name]
    """

    #: A String specifying the name of the Remeshing Rule to which these results correspond.
    name: str

    #: A repository of ErrorIndicatorResult objects specifying the calculated results from the
    #: sizing function corresponding to the error indicator variables for the Remeshing Rule.
    indicatorResults: typing.Dict[str, ErrorIndicatorResult]

    #: An Int specifying the number of elements before remeshing in the region of the Remeshing
    #: Rule.
    numElems: int

    #: An Int specifying the number of elements that were constrained to the minimum element
    #: size by the Remeshing Rule.
    minSizeElemCount: int

    #: A sequence of Strings specifying the error indicator variables that have satisfied the
    #: Remeshing Rule.
    satisfiedVars: tuple = ()

    def __init__(
        self,
        name: str,
        indicatorResults: typing.Dict[str, ErrorIndicatorResult],
        numElems: int,
        minSizeElemCount: int,
        satisfiedVars: tuple = (),
    ):
        """This method creates a RuleResult with data for a RemeshingRule for a given adaptivity
        iteration.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.adaptivityProcesses[name].iterations[i].RuleResult

        Parameters
        ----------
        name
            A String specifying the name of the Remeshing Rule to which these results correspond.
        indicatorResults
            A repository of ErrorIndicatorResult objects specifying the calculated results from the
            sizing function corresponding to the error indicator variables for the Remeshing Rule.
        numElems
            An Int specifying the number of elements before remeshing in the region of the Remeshing
            Rule.
        minSizeElemCount
            An Int specifying the number of elements that were constrained to the minimum element
            size by the Remeshing Rule.
        satisfiedVars
            A sequence of Strings specifying the error indicator variables that have satisfied the
            Remeshing Rule.

        Returns
        -------
        RuleResult
            A :py:class:`~abaqus.Adaptivity.RuleResult.RuleResult` object.

        Raises
        ------
        AbaqusException
        """
        ...



import typing

from ..PlotOptions.DGSymbolOptions import DGSymbolOptions
from ..UtilityAndView.abaqusConstants import *


class SymbolOptions(DGSymbolOptions):
    """The SymbolOptions object stores values and attributes associated with a symbol plot. The
    SymbolOptions object has no constructor command. Abaqus creates a
    *defaultOdbDisplay.symbolOptions* member when you import the Visualization module.
    Abaqus creates a **symbolOptions** member when it creates the OdbDisplay object, using the
    values from *defaultOdbDisplay.symbolOptions*. Abaqus creates the **odbDisplay** member
    when a viewport is created, using the values from **defaultOdbDisplay**.
    SymbolOptions objects are accessed in one of two ways:
    - The default symbol options. These settings are used as defaults when other
    **symbolOptions** members are created. These settings can be set to customize user
    preferences.
    - The symbol options associated with a particular viewport.
    The SymbolOptions object is derived from the DGSymbolOptions object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.defaultOdbDisplay.symbolOptions
            session.viewports[name].assemblyDisplay.displayGroupInstances[name].odbDisplayOptions.symbolOptions
            session.viewports[name].layers[name].assemblyDisplay.displayGroupInstances[name].odbDisplayOptions.symbolOptions
            session.viewports[name].layers[name].odbDisplay.displayGroupInstances[name].odbDisplayOptions.symbolOptions
            session.viewports[name].layers[name].odbDisplay.symbolOptions
            session.viewports[name].layers[name].partDisplay.displayGroupInstances[name].odbDisplayOptions.symbolOptions
            session.viewports[name].odbDisplay.displayGroupInstances[name].odbDisplayOptions.symbolOptions
            session.viewports[name].odbDisplay.symbolOptions
            session.viewports[name].partDisplay.displayGroupInstances[name].odbDisplayOptions.symbolOptions
    """

    #: A SymbolicConstant specifying the vector quantity to display. Possible values are
    #: RESULTANT and VECTOR_COMPONENT. The default value is RESULTANT.
    vectorQuantity: SymbolicConstant = RESULTANT

    #: A Boolean specifying whether the maximum vector value is to be computed automatically.
    #: The default value is ON.
    vectorMaxValueAutoCompute: Boolean = ON

    #: A Float specifying the user-specified maximum vector value. The default value is
    #: **autoVectorMaxValue**.
    vectorMaxValue: float = None

    #: A Boolean specifying whether the minimum vector value is to be computed automatically.
    #: The default value is ON.
    vectorMinValueAutoCompute: Boolean = ON

    #: A Float specifying the user-specified minimum vector value. The default value is
    #: **autoVectorMinValue**.
    vectorMinValue: float = None

    #: A SymbolicConstant specifying the tensor quantity to display. Possible values are
    #: ALL_PRINCIPAL_COMPONENTS, PRINCIPAL_COMPONENT, ALL_DIRECT_COMPONENTS, and
    #: DIRECT_COMPONENT. The default value is ALL_PRINCIPAL_COMPONENTS.
    tensorQuantity: SymbolicConstant = ALL_PRINCIPAL_COMPONENTS

    #: A Boolean specifying whether the maximum tensor value is to be computed automatically.
    #: The default value is ON.
    tensorMaxValueAutoCompute: Boolean = ON

    #: A Float specifying the user-specified maximum tensor value. The default value is
    #: **autoTensorMaxValue**.
    tensorMaxValue: float = None

    #: A Boolean specifying whether the minimum tensor value is to be computed automatically.
    #: The default value is ON.
    tensorMinValueAutoCompute: Boolean = ON

    #: A Float specifying the user-specified minimum tensor value. The default value is
    #: **autoTensorMinValue**.
    tensorMinValue: float = None

    #: The SymbolicConstant NOT_SET or a Float specifying the vector maximum value when
    #: **vectorMaxValueAutoCompute** = ON. This value is read-only. The default value is NOT_SET.
    autoVectorMaxValue: typing.Union[SymbolicConstant, float] = NOT_SET

    #: The SymbolicConstant NOT_SET or a Float specifying the vector minimum value when
    #: **vectorMinValueAutoCompute** = ON. This value is read-only. The default value is NOT_SET.
    autoVectorMinValue: typing.Union[SymbolicConstant, float] = NOT_SET

    #: The SymbolicConstant NOT_SET or a Float specifying the tensor maximum value when
    #: **tensorMaxValueAutoCompute** = ON. This value is read-only. The default value is NOT_SET.
    autoTensorMaxValue: typing.Union[SymbolicConstant, float] = NOT_SET

    #: The SymbolicConstant NOT_SET or a Float specifying the tensor minimum value when
    #: **tensorMinValueAutoCompute** = ON. This value is read-only. The default value is NOT_SET.
    autoTensorMinValue: typing.Union[SymbolicConstant, float] = NOT_SET

    #: A SymbolicConstant specifying the vector line thickness. Possible values are VERY_THIN,
    #: THIN, MEDIUM, and THICK. The default value is VERY_THIN.
    vectorLineThickness: SymbolicConstant = VERY_THIN

    #: A SymbolicConstant specifying the vector color method. Possible values are UNIFORM and
    #: SPECTRUM. The default value is SPECTRUM.
    vectorColorMethod: SymbolicConstant = SPECTRUM

    #: A SymbolicConstant specifying the tensor color method. Possible values are UNIFORM and
    #: SPECTRUM. The default value is SPECTRUM.
    tensorColorMethod: SymbolicConstant = SPECTRUM

    #: A SymbolicConstant specifying the vector arrowhead style. Possible values are NONE,
    #: FILLED, and WIRE. The default value is WIRE.
    vectorArrowheadStyle: SymbolicConstant = WIRE

    #: An Int specifying the length of vector and tensor symbols. The default value is 6.
    arrowSymbolSize: int = 6

    #: An Int specifying the number of color intervals for vector symbols. The default value is
    #: 12.
    vectorIntervalNumber: int = 12

    #: A Float specifying the factor for randomized sampling. The default value is 1.0.
    symbolDensity: float = 1

    #: A Boolean specifying whether to use constant-length arrows for vector symbols. The
    #: default value is OFF.
    constantLengthArrows: Boolean = OFF

    #: An Int specifying the number of color intervals for tensor symbols. The default value is
    #: 12.
    tensorIntervalNumber: int = 12

    #: A SymbolicConstant specifying the line thickness of the tensor symbols. Possible values
    #: are VERY_THIN, THIN, MEDIUM, and THICK. The default value is VERY_THIN.
    tensorLineThickness: SymbolicConstant = VERY_THIN

    #: A SymbolicConstant specifying the arrowhead style of the tensor symbols. Possible values
    #: are NONE, FILLED, and WIRE. The default value is WIRE.
    tensorArrowheadStyle: SymbolicConstant = WIRE

    #: A SymbolicConstant specifying the number format for tensor. Possible values are
    #: SCIENTIFIC, FIXED, and ENGINEERING. The default value is SCIENTIFIC.
    numberFormatT: SymbolicConstant = SCIENTIFIC

    #: A SymbolicConstant specifying the number format for vector. Possible values are
    #: SCIENTIFIC, FIXED, and ENGINEERING. The default value is SCIENTIFIC.
    numberFormatV: SymbolicConstant = SCIENTIFIC

    #: A SymbolicConstant specifying the arrow scaling mode. Possible values are MODEL_SIZE and
    #: SCREEN_SIZE. The default value is MODEL_SIZE.
    arrowScaleMode: SymbolicConstant = MODEL_SIZE

    #: A Boolean specifying whether to draw tensor labels. The default value is OFF.
    drawLabelT: Boolean = OFF

    #: A Boolean specifying whether to draw vector labels. The default value is OFF.
    drawLabelV: Boolean = OFF

    #: An Int specifying the number of digits in the tensor label. The default value is 2.
    numDigitsT: int = 2

    #: An Int specifying the number of digits in the vector label. The default value is 2.
    numDigitsV: int = 2

    #: A String specifying the vector color. The default value is "Red".
    vectorColor: str = ""

    #: A String specifying the vector color spectrum name. The default value is "Rainbow".
    vectorColorSpectrum: str = ""

    #: A String specifying the tensor color spectrum name. The default value is "Rainbow".
    tensorColorSpectrum: str = ""

    #: A String specifying the text color for tensor. The default value is "Yellow".
    textColorT: str = ""

    #: A String specifying the text color for vector. The default value is "Yellow".
    textColorV: str = ""

    #: A String specifying the text font for tensor. The default value is "verdana".
    textFontT: str = ""

    #: A String specifying the text font for vector. The default value is "verdana".
    textFontV: str = ""

    #: A String specifying the color of the maximum principal tensor symbols. The default value
    #: is "Red".
    tensorMaxPrinColor: str = ""

    #: A String specifying the color of the minimum principal tensor symbols. The default value
    #: is "Cyan".
    tensorMinPrinColor: str = ""

    #: A String specifying the color of the intermediate principal tensor symbols. The default
    #: value is "Yellow".
    tensorMidPrinColor: str = ""

    #: A String specifying the color of the selected principal tensor symbols. The default
    #: value is "Red".
    tensorSelectedPrinColor: str = ""

    def setValues(
        self,
        options: "SymbolOptions" = None,
        vectorQuantity: SymbolicConstant = RESULTANT,
        vectorLineThickness: SymbolicConstant = VERY_THIN,
        vectorArrowheadStyle: SymbolicConstant = WIRE,
        vectorColor: str = "",
        vectorColorMethod: SymbolicConstant = SPECTRUM,
        vectorColorSpectrum: str = "",
        vectorIntervalNumber: int = 12,
        symbolDensity: float = 1,
        constantLengthArrows: Boolean = OFF,
        tensorColorMethod: SymbolicConstant = SPECTRUM,
        tensorColorSpectrum: str = "",
        tensorIntervalNumber: int = 12,
        vectorMaxValueAutoCompute: Boolean = ON,
        vectorMaxValue: float = None,
        vectorMinValueAutoCompute: Boolean = ON,
        vectorMinValue: float = None,
        tensorQuantity: SymbolicConstant = ALL_PRINCIPAL_COMPONENTS,
        arrowSymbolSize: int = 6,
        tensorMaxPrinColor: str = "",
        tensorMinPrinColor: str = "",
        tensorMidPrinColor: str = "",
        tensorSelectedPrinColor: str = "",
        tensorLineThickness: SymbolicConstant = VERY_THIN,
        tensorArrowheadStyle: SymbolicConstant = WIRE,
        tensorMaxValueAutoCompute: Boolean = ON,
        tensorMaxValue: float = None,
        tensorMinValueAutoCompute: Boolean = ON,
        tensorMinValue: float = None,
    ):
        """This method modifies the SymbolOptions object.

        Parameters
        ----------
        options
            A :py:class:`~abaqus.OdbDisplay.SymbolOptions.SymbolOptions` object from which values are to be copied. If other arguments are also
            supplied to setValues, they will override the values in **options**. The default value is
            None.
        vectorQuantity
            A SymbolicConstant specifying the vector quantity to display. Possible values are
            RESULTANT and VECTOR_COMPONENT. The default value is RESULTANT.
        vectorLineThickness
            A SymbolicConstant specifying the vector line thickness. Possible values are VERY_THIN,
            THIN, MEDIUM, and THICK. The default value is VERY_THIN.
        vectorArrowheadStyle
            A SymbolicConstant specifying the vector arrowhead style. Possible values are NONE,
            FILLED, and WIRE. The default value is WIRE.
        vectorColor
            A String specifying the vector color. The default value is "Red".
        vectorColorMethod
            A SymbolicConstant specifying the vector color method. Possible values are UNIFORM and
            SPECTRUM. The default value is SPECTRUM.
        vectorColorSpectrum
            A String specifying the vector color spectrum name. The default value is "Rainbow".
        vectorIntervalNumber
            An Int specifying the number of color intervals for vector symbols. The default value is
            12.
        symbolDensity
            A Float specifying the factor for randomized sampling. The default value is 1.0.
        constantLengthArrows
            A Boolean specifying whether to use constant-length arrows for vector symbols. The
            default value is OFF.
        tensorColorMethod
            A SymbolicConstant specifying the tensor color method. Possible values are UNIFORM and
            SPECTRUM. The default value is SPECTRUM.
        tensorColorSpectrum
            A String specifying the tensor color spectrum name. The default value is "Rainbow".
        tensorIntervalNumber
            An Int specifying the number of color intervals for tensor symbols. The default value is
            12.
        vectorMaxValueAutoCompute
            A Boolean specifying whether the maximum vector value is to be computed automatically.
            The default value is ON.
        vectorMaxValue
            A Float specifying the user-specified maximum vector value. The default value is
            **autoVectorMaxValue**.
        vectorMinValueAutoCompute
            A Boolean specifying whether the minimum vector value is to be computed automatically.
            The default value is ON.
        vectorMinValue
            A Float specifying the user-specified minimum vector value. The default value is
            **autoVectorMinValue**.
        tensorQuantity
            A SymbolicConstant specifying the tensor quantity to display. Possible values are
            ALL_PRINCIPAL_COMPONENTS, PRINCIPAL_COMPONENT, ALL_DIRECT_COMPONENTS, and
            DIRECT_COMPONENT. The default value is ALL_PRINCIPAL_COMPONENTS.
        arrowSymbolSize
            An Int specifying the length of vector and tensor symbols. The default value is 6.
        tensorMaxPrinColor
            A String specifying the color of the maximum principal tensor symbols. The default value
            is "Red".
        tensorMinPrinColor
            A String specifying the color of the minimum principal tensor symbols. The default value
            is "Cyan".
        tensorMidPrinColor
            A String specifying the color of the intermediate principal tensor symbols. The default
            value is "Yellow".
        tensorSelectedPrinColor
            A String specifying the color of the selected principal tensor symbols. The default
            value is "Red".
        tensorLineThickness
            A SymbolicConstant specifying the line thickness of the tensor symbols. Possible values
            are VERY_THIN, THIN, MEDIUM, and THICK. The default value is VERY_THIN.
        tensorArrowheadStyle
            A SymbolicConstant specifying the arrowhead style of the tensor symbols. Possible values
            are NONE, FILLED, and WIRE. The default value is WIRE.
        tensorMaxValueAutoCompute
            A Boolean specifying whether the maximum tensor value is to be computed automatically.
            The default value is ON.
        tensorMaxValue
            A Float specifying the user-specified maximum tensor value. The default value is
            **autoTensorMaxValue**.
        tensorMinValueAutoCompute
            A Boolean specifying whether the minimum tensor value is to be computed automatically.
            The default value is ON.
        tensorMinValue
            A Float specifying the user-specified minimum tensor value. The default value is
            **autoTensorMinValue**.

        Raises
        ------
        RangeError
        """
        ...



from .PredefinedField import PredefinedField
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


class Velocity(PredefinedField):
    """The Velocity object stores the data for an initial velocity predefined field.
    The Velocity object is derived from the PredefinedField object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].predefinedFields[name]

        The corresponding analysis keywords are:

        - INITIAL CONDITIONS
    """

    #: A String specifying the repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the predefined field is applied.
    region: Region

    #: A Float specifying the first component of the velocity.
    velocity1: float

    #: A Float specifying the second component of the velocity.
    velocity2: float

    #: A Float specifying the third component of the velocity.
    velocity3: float

    #: A Float specifying the angular velocity.
    omega: float

    #: A sequence of Floats specifying the *X-*, *Y-*, and **Z**- coordinates of the starting
    #: point of the axis about which **omega** is defined.
    axisBegin: tuple

    #: A sequence of Floats specifying the *X-*, *Y-*, and **Z**- coordinates of the end point of
    #: the axis about which **omega** is defined.
    axisEnd: tuple

    #: A String specifying the name of the AnalyticalField object associated with this
    #: predefined field. The **field** argument applies only when
    #: **distributionType** = FIELD_ANALYTICAL. The default value is an empty string.
    field: str = ""

    #: A SymbolicConstant specifying whether the load is uniform. Possible values are MAGNITUDE
    #: and FIELD_ANALYTICAL. The default value is MAGNITUDE.
    distributionType: SymbolicConstant = MAGNITUDE

    def __init__(
        self,
        name: str,
        region: Region,
        velocity1: float,
        velocity2: float,
        velocity3: float,
        omega: float,
        axisBegin: tuple,
        axisEnd: tuple,
        field: str = "",
        distributionType: SymbolicConstant = MAGNITUDE,
    ):
        """This method creates a Velocity predefined field object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].Velocity

        Parameters
        ----------
        name
            A String specifying the repository key.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the predefined field is applied.
        velocity1
            A Float specifying the first component of the velocity.
        velocity2
            A Float specifying the second component of the velocity.
        velocity3
            A Float specifying the third component of the velocity.
        omega
            A Float specifying the angular velocity.
        axisBegin
            A sequence of Floats specifying the *X-*, *Y-*, and **Z**- coordinates of the starting
            point of the axis about which **omega** is defined.
        axisEnd
            A sequence of Floats specifying the *X-*, *Y-*, and **Z**- coordinates of the end point of
            the axis about which **omega** is defined.
        field
            A String specifying the name of the AnalyticalField object associated with this
            predefined field. The **field** argument applies only when
            **distributionType** = FIELD_ANALYTICAL. The default value is an empty string.
        distributionType
            A SymbolicConstant specifying whether the load is uniform. Possible values are MAGNITUDE
            and FIELD_ANALYTICAL. The default value is MAGNITUDE.

        Returns
        -------
        Velocity
            A :py:class:`~abaqus.PredefinedField.Velocity.Velocity` object.
        """
        super().__init__()

    def setValues(
        self, field: str = "", distributionType: SymbolicConstant = MAGNITUDE
    ):
        """This method modifies the Velocity object.

        Parameters
        ----------
        field
            A String specifying the name of the AnalyticalField object associated with this
            predefined field. The **field** argument applies only when
            **distributionType** = FIELD_ANALYTICAL. The default value is an empty string.
        distributionType
            A SymbolicConstant specifying whether the load is uniform. Possible values are MAGNITUDE
            and FIELD_ANALYTICAL. The default value is MAGNITUDE.
        """
        ...



from ..UtilityAndView.abaqusConstants import *


class JobData:
    """The JobData object describes the context in which the analysis was run.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import odbAccess
            session.odbs[name].jobData
    """

    #: A String specifying the name of the job.
    name: str = ""

    #: A SymbolicConstant specifying the analysis code. Possible values are ABAQUS_STANDARD,
    #: ABAQUS_EXPLICIT, and UNKNOWN_ANALYSIS_CODE.
    analysisCode: SymbolicConstant = None

    #: A SymbolicConstant specifying the precision. Only SINGLE_PRECISION is currently
    #: supported. Possible values are DOUBLE_PRECISION and SINGLE_PRECISION.
    precision: SymbolicConstant = None

    #: A String specifying the release of the analysis code.
    version: str = ""

    #: A String specifying the date and time at which the analysis was run.
    creationTime: str = ""

    #: A String specifying the date and time at which the database was last modified.
    modificationTime: str = ""

    #: A String specifying the name of the machine on which the analysis was run.
    machineName: str = ""

    #: A String specifying an odb_Sequence of productAddOns. Possible
    #: values are AQUA, DESIGN, BIORID, CEL, SOLITER, and CAVPARALLEL.
    productAddOns: str = ""



from .Leaf import Leaf
from ..UtilityAndView.abaqusConstants import *


class LeafFromModelNodeLabels(Leaf):
    """The LeafFromModelNodeLabels object can be used whenever a Leaf object is expected as an
    argument. Leaf objects are used to specify the items in a display group. Leaf objects
    are constructed as temporary objects, which are then used as arguments to DisplayGroup
    commands.
    The LeafFromModelNodeLabels object is derived from the Leaf object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import displayGroupOdbToolset
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
    #: DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.
    leafType: SymbolicConstant = None

    #: A sequence of Strings specifying expressions that denote node labels per part instance
    #: in the model. Each part instance node expression is a sequence of a String specifying
    #: the part instance name and a sequence of node expressions; for example,
    #: `(('partInstance1',(1,'7','3:15;3'),), ('partInstance2','8'),))`. The node expressions
    #: can be any of the following:An Int specifying a single node label; for example, `1`.A
    #: String specifying a single node label; for example, `'7'`.A String specifying a sequence
    #: of node labels; for example, `'3:5'` and `'3:15:3'`.
    nodeLabels: tuple

    def __init__(self, nodeLabels: tuple):
        """This method creates a Leaf object from a sequence of node labels spanning several part
        instances.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                LeafFromModelNodeLabels

        Parameters
        ----------
        nodeLabels
            A sequence of Strings specifying expressions that denote node labels per part instance
            in the model. Each part instance node expression is a sequence of a String specifying
            the part instance name and a sequence of node expressions; for example,
            `(('partInstance1',(1,'7','3:15;3'),), ('partInstance2','8'),))`. The node expressions
            can be any of the following:An Int specifying a single node label; for example, `1`.A
            String specifying a single node label; for example, `'7'`.A String specifying a sequence
            of node labels; for example, `'3:5'` and `'3:15:3'`.

        Returns
        -------
        LeafFromModelNodeLabels
            A :py:class:`~abaqus.DisplayGroup.LeafFromModelNodeLabels.LeafFromModelNodeLabels` object.
        """
        super().__init__(DEFAULT_MODEL)



class HeatGeneration:
    """The HeatGeneration object includes volumetric heat generation in heat transfer analyses.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].heatGeneration
            import odbMaterial
            session.odbs[name].materials[name].heatGeneration

        The corresponding analysis keywords are:

        - HEAT GENERATION
    """

    def __init__(self):
        """This method creates a HeatGeneration object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].HeatGeneration
                session.odbs[name].materials[name].HeatGeneration

        Returns
        -------
        HeatGeneration
            A :py:class:`~abaqus.Material.Others.HeatTransfer.HeatGeneration.HeatGeneration` object.
        """
        ...



from __future__ import annotations

class AbaqusBoolean(int):
    """The AbaqusBoolean object is used in a similar way to the SymbolicConstant object. If you
    pass an AbaqusBoolean object to the Python repr() function, the function returns the
    text without quotes. In effect, the text is the variable that, by convention, refers to
    the AbaqusBoolean object.
    An :py:class:`~abaqus.UtilityAndView.AbaqusBoolean.AbaqusBoolean` object has a value of 0 or 1, and an AbaqusBoolean object can be tested
    in an if statement. You can use an AbaqusBoolean object as an argument to a method in
    place of 1 or 0. Conversely, you can pass a 0 or a 1 to an Abaqus Scripting Interface
    method that expects a Boolean argument, and the 0 or 1 will be coerced to the
    appropriate AbaqusBoolean value.
    There are only two possible values for an AbaqusBoolean object: 1 and 0. You can import
    both values from the symbolicConstants module or from the abaqus module. Abaqus
    Scripting Interface commands that expect an AbaqusBoolean object will also accept a
    Python bool (True, False), or a Python int (1, 0).

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            from symbolicConstants import *
            from ..UtilityAndView.abaqusConstants import *
    """

    def __init__(self, value: int) -> None:
        """The AbaqusBoolean method creates an AbaqusBoolean object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                AbaqusBoolean

        Parameters
        ----------
        value
            An Int specifying whether the AbaqusBoolean object will test true or false. Possible
            values are 0 and 1, which will create the AbaqusBoolean method OFF and ON, respectively.

        Returns
        -------
        AbaqusBoolean
            An :py:class:`~abaqus.UtilityAndView.AbaqusBoolean.AbaqusBoolean` object.
        """
        super().__init__()
        if value not in (0, 1):
            raise ValueError(f'AbaqusBoolean must have value argument 0 or 1.  {value} supplied')
    
    def getId(self) -> int:
        ...
    
    def getText(self) -> str:
        if bool(self):
            return 'ON'
        else:
            return 'OFF'
    
    def isTrue(self) -> bool:
        return bool(self)
    
    def __copy__(self) -> AbaqusBoolean:
        ...
    
    def __getstate__(self) -> bool:
        ...
    
    def __hash__(self) -> int:
        ...
    
    @staticmethod  # known case of __new__
    def __new__(cls, *args, **kargs):  # reliably restored by inspect
        # no doc
        pass

    def __reduce__(self) -> tuple:  # known return case of __reduce__
        ...
    
    def __repr__(self) -> str: 
        return self.getText()

    def __setstate__(self, *args) -> None:
        ...
    
    def __str__(self) -> str:
        return self.getText()

    __weakref__ = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default
    """list of weak references to the object (if defined)"""


from ..UtilityAndView.abaqusConstants import *


class GeometricRestrictionDisplayOptions:
    """The GeometricRestrictionDisplayOptions object stores settings that specify how
    assemblies are to be displayed in a particular viewport when
    session.viewports[name].assemblyDisplay.geometricRestrictions=ON
    The GeometricRestrictionDisplayOptions object has no constructor. When you create a new
    viewport, the settings are copied from the current viewport.

    Notes
    -----
    This object can be accessed by:
        session.viewports[name].assemblyDisplay.geometricRestrictionOptions
        session.viewports[name].layers[name].assemblyDisplay.geometricRestrictionOptions
    """

    def setValues(
        self,
        drillControl: Boolean = ON,
        fixedRegion: Boolean = ON,
        frozenArea: Boolean = ON,
        growth: Boolean = ON,
        penetrationCheck: Boolean = ON,
        shapeDemoldControl: Boolean = ON,
        designDirection: Boolean = ON,
        shapeMemberSize: Boolean = ON,
        shapePlanarSymmetry: Boolean = ON,
        shapePointSymmetry: Boolean = ON,
        shapeRotationalSymmetry: Boolean = ON,
        stampControl: Boolean = ON,
        slideRegionControl: Boolean = ON,
        topologyCyclicSymmetry: Boolean = ON,
        topologyDemoldControl: Boolean = ON,
        topologyMemberSize: Boolean = ON,
        topologyPlanarSymmetry: Boolean = ON,
        topologyPointSymmetry: Boolean = ON,
        topologyRotationalSymmetry: Boolean = ON,
        turnControl: Boolean = ON,
    ):
        """This method modifies the GeometricRestrictionDisplayOptions object.

        Parameters
        ----------
        drillControl
            A Boolean specifying whether drill control geometric restriction symbols are shown. The
            default value is ON.
        fixedRegion
            A Boolean specifying whether fixed region geometric restriction symbols are shown. The
            default value is ON.
        frozenArea
            A Boolean specifying whether frozen area geometric restriction symbols are shown. The
            default value is ON.
        growth
            A Boolean specifying whether growth geometric restriction symbols are shown. The default
            value is ON.
        penetrationCheck
            A Boolean specifying whether penetration check geometric restriction symbols are shown.
            The default value is ON.
        shapeDemoldControl
            A Boolean specifying whether demold control (shape) geometric restriction symbols are
            shown. The default value is ON.
        designDirection
            A Boolean specifying whether design direction geometric restriction symbols are shown.
            The default value is ON.
        shapeMemberSize
            A Boolean specifying whether member size (shape) geometric restriction symbols are
            shown. The default value is ON.
        shapePlanarSymmetry
            A Boolean specifying whether planar symmetry (shape) geometric restriction symbols are
            shown. The default value is ON.
        shapePointSymmetry
            A Boolean specifying whether point symmetry (shape) geometric restriction symbols are
            shown. The default value is ON.
        shapeRotationalSymmetry
            A Boolean specifying whether rotational symmetry (shape) geometric restriction symbols
            are shown. The default value is ON.
        stampControl
            A Boolean specifying whether stamp control geometric restriction symbols are shown. The
            default value is ON.
        slideRegionControl
            A Boolean specifying whether slide region control geometric restriction symbols are
            shown. The default value is ON.
        topologyCyclicSymmetry
            A Boolean specifying whether cyclic symmetry geometric restriction symbols are shown.
            The default value is ON.
        topologyDemoldControl
            A Boolean specifying whether demold control (topology) geometric restriction symbols are
            shown. The default value is ON.
        topologyMemberSize
            A Boolean specifying whether member size (topology) geometric restriction symbols are
            shown. The default value is ON.
        topologyPlanarSymmetry
            A Boolean specifying whether planar symmetry (topology) geometric restriction symbols
            are shown. The default value is ON.
        topologyPointSymmetry
            A Boolean specifying whether point symmetry (topology) geometric restriction symbols are
            shown. The default value is ON.
        topologyRotationalSymmetry
            A Boolean specifying whether rotational symmetry (topology) geometric restriction
            symbols are shown. The default value is ON.
        turnControl
            A Boolean specifying whether turn control geometric restriction symbols are shown. The
            default value is ON.

        Raises
        ------
        RangeError
        """
        ...



from .DirectDampingByFrequencyComponentArray import (
    DirectDampingByFrequencyComponentArray,
)


class DirectDampingByFrequency:
    """A :py:class:`~abaqus.StepMiscellaneous.DirectDampingByFrequency.DirectDampingByFrequency` object contains direct damping parameters.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name].directDampingByFrequency
    """

    #: A :py:class:`~abaqus.StepMiscellaneous.DirectDampingByFrequencyComponentArray.DirectDampingByFrequencyComponentArray` object.
    components: DirectDampingByFrequencyComponentArray = []



import typing

from .OdbContactDiagnostics import OdbContactDiagnostics
from .OdbDiagnosticIncrement import OdbDiagnosticIncrement
from ..UtilityAndView.abaqusConstants import *


class OdbDiagnosticStep:
    """The OdbDiagnosticStep object stores step data.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.odbData[name].diagnosticData.steps[i]
    """

    #: A Tuple of the status values. This attribute is read-only.
    activeXplStatus: tuple = ()

    #: A float specifying the characteristic element length for the step. This attribute is
    #: read-only.
    characteristicElementLength: str = ""

    #: A repository of OdbContactDiagnostics objects.
    contactDiagnostics: typing.Dict[str, OdbContactDiagnostics] = {}

    #: A sequence of string specifying the explicit increment status. This attribute is
    #: read-only.
    explicitIncrementStatus: tuple = ()

    #: A String specifying the method (Linear or logarithmic) used for extrapolation. This
    #: attribute is read-only.
    extrapolation: str = ""

    #: A String specifying the method of incrementation (Auto or fixed). This attribute is
    #: read-only.
    incrementationScheme: str = ""

    #: An int specifying the number of completed increments. This attribute is read-only.
    incrementsCompleted: str = ""

    #: A repository of OdbDiagnosticIncrement objects.
    increments: typing.Dict[str, OdbDiagnosticIncrement] = {}

    #: A float specifying the initial increment size for the step. This attribute is read-only.
    initialTimeIncrement: str = ""

    #: A boolean specifying whether or not the effects of geometric nonlinearities are
    #: considered. This attribute is read-only.
    isNlgeom: Boolean = OFF

    #: A boolean specifying whether or not the step is a perturbation step. This attribute is
    #: read-only.
    isPerturbation: Boolean = OFF

    #: A boolean specifying whether or not stabilization for the system in any form is
    #: considered. This attribute is read-only.
    isStabilized: Boolean = OFF

    #: A boolean specifying whether the step is static riks. This attribute is read-only.
    isRiks: Boolean = OFF

    #: A boolean specifying whether the matrix storage is unsymmetric. This attribute is
    #: read-only.
    isUnsymm: Boolean = OFF

    #: A string specifying the method of solving (Direct or Iterative). This attribute is
    #: read-only.
    matrixSolver: str = ""

    #: An int specifying the maximum number of allowed increments in the step. This attribute
    #: is read-only.
    maximumNumberOfIncrements: str = ""

    #: A float specifying the size of the allowed maximum time increment in the step. This
    #: attribute is read-only.
    maximumTimeIncrement: str = ""

    #: A float specifying the size of the allowed minimum time increment in the step. This
    #: attribute is read-only.
    minimumTimeIncrement: str = ""

    #: A string specifying the name of the step. This attribute is read-only.
    name: str = ""

    #: An int specifying the step number. This attribute is read-only.
    number: str = ""

    #: An int specifying the number of contact diagnostics encountered. This attribute is
    #: read-only.
    numberOfContactDiagnostics: str = ""

    #: An int specifying the number of increments taken in the step to complete the solution.
    #: This attribute is read-only.
    numberOfIncrements: str = ""

    #: An int specifying the number of the explicit status. This attribute is read-only.
    numberOfXplStatus: str = ""

    #: A float specifying the stabilize factor. This attribute is read-only.
    stabilizeFactor: str = ""

    #: A float specifying the time taken for the completion of the step. This attribute is
    #: read-only.
    stepTimeCompleted: str = ""

    #: A float specifying the duration for the step. This attribute is read-only.
    timePeriod: str = ""

    def extractData(self, incrementStatistics: str):
        """This method creates a temporary XYData object, with increments on the x-axis and
        requested output on the y-axis.

        Parameters
        ----------
        incrementStatistics
            An enum specifying the requested output variable for the data table. Possible enum
            values are NUM_ATTEMPTS (the number of attempts), NUM_SDI (the number of severe
            discontinuity iterations), NUM_EQI (the number of equivalent iterations), NUM_ITERS (the
            number of iterations), STEP_TIME (the cumulative step time until that increment) or
            INC_SIZE (the step time for each increment).
        """
        ...



import typing

from .OdbInstanceBase import OdbInstanceBase
from .OdbMeshNode import OdbMeshNode
from .OdbSet import OdbSet


class OdbInstance(OdbInstanceBase):

    def NodeSet(self, name: str, nodes: typing.Tuple[OdbMeshNode, ...]) -> OdbSet:
        """This method creates a node set from an array of OdbMeshNode objects (for part
        instance-level sets) or from a sequence of arrays of OdbMeshNode objects (for
        assembly-level sets).

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                session.odbs[name].parts[name].NodeSet
                session.odbs[name].rootAssembly.instances[name].NodeSet
                session.odbs[name].rootAssembly.NodeSet

        Parameters
        ----------
        name
            A String specifying the name of the set and the repository key.
        nodes
            A sequence of OdbMeshNode objects. For example, for a part:`nodes=part1.nodes[1:5]`For
            an assembly:`nodes=(instance1.nodes[6:7], instance2.nodes[1:5])`

        Returns
        -------
        OdbSet
            An :py:class:`~abaqus.Odb.OdbSet.OdbSet` object.
        """
        self.nodeSets[name] = odbSet = OdbSet(name, nodes)
        return odbSet



from ....UtilityAndView.abaqusConstants import *


class Hypoelastic:
    r"""The Hypoelastic object specifies hypoelastic material properties.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].hypoelastic
            import odbMaterial
            session.odbs[name].materials[name].hypoelastic

        The table data for this object are:

        - Instantaneous Young's modulus, :math:`E`.
        - Instantaneous Poisson's ratio, :math:`\nu`.
        - First strain invariant, :math:`I_1`.
        - Second strain invariant, :math:`I_2`.
        - Third strain invariant, :math:`I_3`.

        The corresponding analysis keywords are:

        - HYPOELASTIC
    """

    def __init__(self, table: tuple, user: Boolean = OFF):
        """This method creates a Hypoelastic object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].Hypoelastic
                session.odbs[name].materials[name].Hypoelastic

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        user
            A Boolean specifying that hypoelasticity is defined by user subroutine UHYPEL. The
            default value is OFF.

        Returns
        -------
        Hypoelastic
            A :py:class:`~abaqus.Material.Elastic.HypoElastic.Hypoelastic.Hypoelastic` object.
        """
        ...

    def setValues(self, *args, **kwargs):
        """This method modifies the Hypoelastic object."""
        ...



import os
from sphinx.application import Sphinx

sphinx = Sphinx('docs\\source', 'docs\\source', 'docs\\build\html', 'docs\\build\\doctrees', 'html')
sphinx.build()

sphinx = Sphinx('docs\\source', 'docs\\source', 'docs\\build\\latex', 'docs\\build\\doctrees', 'latex')
sphinx.build()

os.chdir('docs\\build\\latex')
os.system('xelatex abqpy')
os.system('xelatex abqpy')



from ..UtilityAndView.abaqusConstants import *


class DGSuperimposeOptions:
    """The DGSuperimposeOptions object stores values and attributes associated with the
    undeformed shape when the display contains both the deformed shape and the undeformed
    shape. The DGSuperimposeOptions object has no constructor command. Abaqus creates an
    *odbDisplayOptions.superimposeOptions* member when a display group instance is created,
    using values from *odbDisplay.superimposeOptions*.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            session.viewports[name].assemblyDisplay.displayGroupInstances[name].odbDisplayOptions.superimposeOptions
            session.viewports[name].layers[name].assemblyDisplay.displayGroupInstances[name].odbDisplayOptions.superimposeOptions
            session.viewports[name].layers[name].odbDisplay.displayGroupInstances[name].odbDisplayOptions.superimposeOptions
            session.viewports[name].layers[name].partDisplay.displayGroupInstances[name].odbDisplayOptions.superimposeOptions
            session.viewports[name].odbDisplay.displayGroupInstances[name].odbDisplayOptions.superimposeOptions
            session.viewports[name].partDisplay.displayGroupInstances[name].odbDisplayOptions.superimposeOptions
    """

    #: A SymbolicConstant specifying the render style of the plot. Possible values are
    #: WIREFRAME, FILLED, HIDDEN, and SHADED. The default value is WIREFRAME.
    renderStyle: SymbolicConstant = WIREFRAME

    #: A SymbolicConstant specifying which edges to plot. Possible values are ALL, EXTERIOR,
    #: FEATURE, FREE, and NONE. The default value is FEATURE.NONE can be used only when
    #: **renderStyle** = SHADED.
    visibleEdges: SymbolicConstant = FEATURE

    #: A SymbolicConstant specifying the edge line style. Possible values are SOLID, DASHED,
    #: DOTTED, and DOT_DASH. The default value is SOLID.
    edgeLineStyle: SymbolicConstant = SOLID

    #: A SymbolicConstant specifying the edge line thickness. Possible values are VERY_THIN,
    #: THIN, MEDIUM, and THICK. The default value is VERY_THIN.
    edgeLineThickness: SymbolicConstant = VERY_THIN

    #: A Boolean specifying whether to allow color coded items in the output database to
    #: override the edge and fill color settings. The default value is ON.
    colorCodeOverride: Boolean = ON

    #: A Boolean specifying whether to plot the element labels. The default value is OFF.
    elemLabels: Boolean = OFF

    #: A Boolean specifying whether to plot the face labels. The default value is OFF.
    faceLabels: Boolean = OFF

    #: A Boolean specifying whether to plot the node labels. The default value is OFF.
    nodeLabels: Boolean = OFF

    #: A Boolean specifying whether to plot the node symbols. The default value is OFF.
    nodeSymbols: Boolean = OFF

    #: A SymbolicConstant specifying the node symbol types. Possible values are:
    #: 
    #: - FILLED_CIRCLE
    #: - FILLED_SQUARE
    #: - FILLED_DIAMOND
    #: - FILLED_TRI
    #: - HOLLOW_CIRCLE
    #: - HOLLOW_SQUARE
    #: - HOLLOW_DIAMOND
    #: - HOLLOW_TRI
    #: - CROSS
    #: - XMARKER
    #: The default value is HOLLOW_CIRCLE.
    nodeSymbolType: SymbolicConstant = HOLLOW_CIRCLE

    #: A SymbolicConstant specifying the node symbol size. Possible values are SMALL, MEDIUM,
    #: and LARGE. The default value is SMALL.
    nodeSymbolSize: SymbolicConstant = SMALL

    #: A Boolean specifying whether elements are displayed in a shrunk format. The default
    #: value is OFF.
    elementShrink: Boolean = OFF

    #: An Int specifying the percentage to shrink the elements when **elementShrink** = ON.
    #: Possible values are 0≤ **elementShrinkPercentage** ≤ 90. The default value is 5.
    elementShrinkFactor: int = 5

    #: A Boolean specifying whether to scale coordinates. The default value is OFF.
    coordinateScale: Boolean = OFF

    #: A Boolean specifying whether to draw arrows that indicate the directions of element and
    #: surface normals. The default value is OFF.
    normals: Boolean = OFF

    #: A SymbolicConstant specifying whether to draw element normals and surface normals.
    #: Possible values are ELEMENT and SURFACE. The default value is ELEMENT.
    normalDisplay: SymbolicConstant = ELEMENT

    #: A SymbolicConstant specifying the length of the normal arrows. Possible values are
    #: SHORT, MEDIUM, and LONG. The default value is MEDIUM.
    normalArrowLength: SymbolicConstant = MEDIUM

    #: A SymbolicConstant specifying the thickness of the normal arrows. Possible values are
    #: VERY_THIN, THIN, MEDIUM, and THICK. The default value is VERY_THIN.
    normalLineThickness: SymbolicConstant = VERY_THIN

    #: A SymbolicConstant specifying the arrowhead style of the normal arrows. Possible values
    #: are NONE, FILLED, and WIRE. The default value is WIRE.
    normalArrowheadStyle: SymbolicConstant = WIRE

    #: A Boolean specifying whether to set translucency. The default value is OFF.
    translucency: Boolean = OFF

    #: A Float specifying the translucency factor when **translucency** = ON. Possible values are
    #: 0.0≤ **translucencyFactor** ≤ 1.0. The default value is 0.3.
    translucencyFactor: float = 0

    #: A String specifying the color to be used to plot the edges of the model when
    #: **renderStyle** = WIREFRAME or HIDDEN. The default value is "Green".
    edgeColorWireHide: str = ""

    #: A String specifying the color to be used to plot the edges of the model when
    #: **renderStyle** = FILLED or SHADED. The default value is "Black".
    edgeColorFillShade: str = ""

    #: A String specifying the color to be used to fill elements when **renderStyle** = FILLED or
    #: SHADED. The default value is "Green".
    fillColor: str = ""

    #: A String specifying the label font to be used for all model labels. The default value is
    #: "-*-courier-medium-r-normal-*-*-120-*-*-m-*-*-*".
    labelFont: str = ""

    #: A String specifying the color to be used to plot the element labels. The default value
    #: is "Cyan".
    elemLabelColor: str = ""

    #: A String specifying the color to be used to plot the face labels. The default value is
    #: "Red".
    faceLabelColor: str = ""

    #: A String specifying the color to be used to plot the node labels. The default value is
    #: "Yellow".
    nodeLabelColor: str = ""

    #: A String specifying the color to be used to plot the node symbols. The default value is
    #: "Yellow".
    nodeSymbolColor: str = ""

    #: A String specifying the color to be used to plot the normal to a nonbeam element or to a
    #: surface. The default value is "Red".
    faceNormalColor: str = ""

    #: A String specifying the color to be used to plot an arrow along the beam n1n1-direction.
    #: The default value is "Blue".
    beamN1Color: str = ""

    #: A String specifying the color to be used to plot an arrow along the beam n2n2-direction.
    #: The default value is "Red".
    beamN2Color: str = ""

    #: A String specifying the color to be used to plot an arrow along the tangent to a beam.
    #: The default value is "White".
    beamTangentColor: str = ""

    #: A tuple of three Floats specifying the coordinate scaling in each of the three
    #: coordinate directions when **coordinateScale** = ON. The default value is (1, 1, 1).
    coordinateScaleFactors: float = None



class CouplingConstraint:
    """The CouplingConstraint object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.odbData[name].kinematicCouplings[i]
            session.odbData[name].distributingCouplings[i]
            session.odbData[name].shellSolidCouplings[i]
    """

    #: A String specifying the coupling name. This attribute is read-only.
    name: str = ""

    #: A String specifying the type of coupling. This attribute is read-only.
    type: str = ""

    def constraintData(self):
        """This method returns node numbers of the surface being controlled by the control point.

        Returns
        -------
        Tuple-of-Ints Dictionary specifying the node numbers on the controlled surface.
        """
        # TODO: Implement this method
        ...



import typing

from .Load import Load
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


class ConcentratedForce(Load):
    """The ConcentratedForce object defines a concentrated force.
    The ConcentratedForce object is derived from the Load object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].loads[name]
    """

    #: A String specifying the load repository key.
    name: str = ""

    #: A SymbolicConstant specifying how the load is distributed spatially. Possible values are
    #: UNIFORM and FIELD. The default value is UNIFORM.
    distributionType: SymbolicConstant = UNIFORM

    #: A Boolean specifying whether the direction of the force rotates with the rotation at
    #: each node of the region. You should provide the **follower** argument only if it is valid
    #: for the specified step. The default value is OFF.
    follower: Boolean = OFF

    #: None or a DatumCsys object specifying the local coordinate system of the load's degrees
    #: of freedom. If **localCsys** = None, the degrees of freedom are defined in the global
    #: coordinate system. When this member is queried, it returns an Int. The default value is
    #: None.
    localCsys: int = None

    #: A String specifying the name of the AnalyticalField object associated with this load.
    #: The **field** argument applies only when **distributionType** = FIELD. The default value is an
    #: empty string.
    field: str = ""

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the load is applied.
    region: Region = Region()

    def __init__(
        self,
        name: str,
        createStepName: str,
        region: Region,
        distributionType: SymbolicConstant = UNIFORM,
        field: str = "",
        cf1: float = None,
        cf2: float = None,
        cf3: float = None,
        amplitude: str = UNSET,
        follower: Boolean = OFF,
        localCsys: int = None,
    ):
        """This method creates a ConcentratedForce object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].ConcentratedForce

        Parameters
        ----------
        name
            A String specifying the load repository key.
        createStepName
            A String specifying the name of the step in which the load is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the load is applied.
        distributionType
            A SymbolicConstant specifying how the load is distributed spatially. Possible values are
            UNIFORM and FIELD. The default value is UNIFORM.
        field
            A String specifying the name of the AnalyticalField object associated with this load.
            The **field** argument applies only when **distributionType** = FIELD. The default value is an
            empty string.
        cf1
            A Float or a Complex specifying the concentrated force component in the 1-direction.
            Although **cf1**, **cf2**, and **cf3** are optional arguments, at least one of them must be
            nonzero.
        cf2
            A Float or a Complex specifying the concentrated force component in the 2-direction.
        cf3
            A Float or a Complex specifying the concentrated force component in the 3-direction.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        follower
            A Boolean specifying whether the direction of the force rotates with the rotation at
            each node of the region. You should provide the **follower** argument only if it is valid
            for the specified step. The default value is OFF.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the load's degrees
            of freedom. If **localCsys** = None, the degrees of freedom are defined in the global
            coordinate system. When this member is queried, it returns an Int. The default value is
            None.

        Returns
        -------
        ConcentratedForce
            A :py:class:`~abaqus.Load.ConcentratedForce.ConcentratedForce` object.
        """
        super().__init__()

    def setValues(
        self,
        distributionType: SymbolicConstant = UNIFORM,
        field: str = "",
        cf1: float = None,
        cf2: float = None,
        cf3: float = None,
        amplitude: str = UNSET,
        follower: Boolean = OFF,
        localCsys: int = None,
    ):
        """This method modifies the data for an existing ConcentratedForce object in the step where
        it is created.

        Parameters
        ----------
        distributionType
            A SymbolicConstant specifying how the load is distributed spatially. Possible values are
            UNIFORM and FIELD. The default value is UNIFORM.
        field
            A String specifying the name of the AnalyticalField object associated with this load.
            The **field** argument applies only when **distributionType** = FIELD. The default value is an
            empty string.
        cf1
            A Float or a Complex specifying the concentrated force component in the 1-direction.
            Although **cf1**, **cf2**, and **cf3** are optional arguments, at least one of them must be
            nonzero.
        cf2
            A Float or a Complex specifying the concentrated force component in the 2-direction.
        cf3
            A Float or a Complex specifying the concentrated force component in the 3-direction.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        follower
            A Boolean specifying whether the direction of the force rotates with the rotation at
            each node of the region. You should provide the **follower** argument only if it is valid
            for the specified step. The default value is OFF.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the load's degrees
            of freedom. If **localCsys** = None, the degrees of freedom are defined in the global
            coordinate system. When this member is queried, it returns an Int. The default value is
            None.
        """
        ...

    def setValuesInStep(
        self,
        stepName: str,
        cf1: typing.Union[SymbolicConstant, float] = None,
        cf2: typing.Union[SymbolicConstant, float] = None,
        cf3: typing.Union[SymbolicConstant, float] = None,
        amplitude: str = "",
    ):
        """This method modifies the propagating data for an existing ConcentratedForce object in
        the specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the load is modified.
        cf1
            A Float, a Complex, or the SymbolicConstant UNCHANGED specifying the concentrated force
            component in the 1-direction. UNCHANGED should be used if the concentrated force
            component is propagated from the previous analysis step.
        cf2
            A Float, a Complex, or the SymbolicConstant UNCHANGED specifying the concentrated force
            component in the 2-direction. UNCHANGED should be used if the concentrated force
            component is propagated from the previous analysis step.
        cf3
            A Float, a Complex, or the SymbolicConstant UNCHANGED specifying the concentrated force
            component in the 3-direction. UNCHANGED should be used if the concentrated force
            component is propagated from the previous analysis step.
        amplitude
            A String or a SymbolicConstant specifying the name of the amplitude reference. Possible
            values for the SymbolicConstant are UNCHANGED and FREED. UNCHANGED should be used if the
            amplitude is propagated from the previous analysis step. FREED should be used if the
            load is changed to have no amplitude reference. You should provide the **amplitude**
            argument only if it is valid for the specified step.
        """
        ...



class BaselineCorrection:
    """The BaselineCorrection object modifies an acceleration history to minimize the overall
    drift of the displacement obtained from the time integration of the given acceleration.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import amplitude
            mdb.models[name].amplitudes[name].baselineCorrection
            import odbAmplitude
            session.odbs[name].amplitudes[name].baselineCorrection

        The corresponding analysis keywords are:

        - BASELINE CORRECTION
    """

    #: A sequence of Floats specifying the correction time interval end points. Possible values
    #: are positive and monotonically increasing Floats. The default value is an empty
    #: sequence.
    intervals: tuple = ()

    def __init__(self, intervals: tuple = ()):
        """This method creates a BaselineCorrection object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].amplitudes[name].BaselineCorrection
                session.odbs[name].amplitudes[name].BaselineCorrection

        Parameters
        ----------
        intervals
            A sequence of Floats specifying the correction time interval end points. Possible values
            are positive and monotonically increasing Floats. The default value is an empty
            sequence.

        Returns
        -------
        BaselineCorrection
            A :py:class:`~abaqus.Amplitude.BaselineCorrection.BaselineCorrection` object.

        Raises
        ------
        RangeError
        """
        ...

    def setValues(self, *args, **kwargs):
        """This method modifies the BaselineCorrection object.

        Raises
        ------
        RangeError
        """
        ...



import typing

from .AnalysisStep import AnalysisStep
from ..Adaptivity.AdaptiveMeshConstraintState import AdaptiveMeshConstraintState
from ..Adaptivity.AdaptiveMeshDomain import AdaptiveMeshDomain
from ..BoundaryCondition.BoundaryConditionState import BoundaryConditionState
from ..Load.LoadCase import LoadCase
from ..Load.LoadState import LoadState
from ..PredefinedField.PredefinedFieldState import PredefinedFieldState
from ..StepMiscellaneous.CompositeDamping import CompositeDamping
from ..StepMiscellaneous.Control import Control
from ..StepMiscellaneous.DirectDamping import DirectDamping
from ..StepMiscellaneous.DirectDampingByFrequency import DirectDampingByFrequency
from ..StepMiscellaneous.RandomResponseFrequencyArray import (
    RandomResponseFrequencyArray,
)
from ..StepMiscellaneous.RayleighDamping import RayleighDamping
from ..StepMiscellaneous.RayleighDampingByFrequency import RayleighDampingByFrequency
from ..StepMiscellaneous.SolverControl import SolverControl
from ..StepMiscellaneous.StructuralDamping import StructuralDamping
from ..StepMiscellaneous.StructuralDampingByFrequency import (
    StructuralDampingByFrequency,
)
from ..StepOutput.DiagnosticPrint import DiagnosticPrint
from ..StepOutput.FieldOutputRequestState import FieldOutputRequestState
from ..StepOutput.HistoryOutputRequestState import HistoryOutputRequestState
from ..StepOutput.Monitor import Monitor
from ..StepOutput.Restart import Restart
from ..UtilityAndView.abaqusConstants import *


class RandomResponseStep(AnalysisStep):
    """The RandomResponseStep object is used to give the linearized response of a model to
    random excitation.
    The RandomResponseStep object is derived from the AnalysisStep object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name]

        The corresponding analysis keywords are:

        - DAMPING
                - MODAL DAMPING
                - RANDOM RESPONSE
                - STEP
    """

    #: A String specifying the repository key.
    name: str = ""

    #: A SymbolicConstant specifying the frequency scale. Possible values are LINEAR and LOG.
    #: The default value is LOG.
    scale: SymbolicConstant = LOG

    #: A String specifying the name of the previous step. The new step appears after this step
    #: in the list of analysis steps.
    previous: str = ""

    #: A String specifying a description of the new step. The default value is an empty string.
    description: str = ""

    #: A :py:class:`~abaqus.StepMiscellaneous.RandomResponseFrequencyArray.RandomResponseFrequencyArray` object specifying frequencies over ranges of modes.
    freq: RandomResponseFrequencyArray = []

    #: A :py:class:`~abaqus.StepMiscellaneous.DirectDamping.DirectDamping` object.
    directDamping: DirectDamping = DirectDamping()

    #: A :py:class:`~abaqus.StepMiscellaneous.CompositeDamping.CompositeDamping` object.
    compositeDamping: CompositeDamping = CompositeDamping()

    #: A :py:class:`~abaqus.StepMiscellaneous.RayleighDamping.RayleighDamping` object.
    rayleighDamping: RayleighDamping = RayleighDamping()

    #: A :py:class:`~abaqus.StepMiscellaneous.StructuralDamping.StructuralDamping` object.
    structuralDamping: StructuralDamping = StructuralDamping()

    #: A :py:class:`~abaqus.StepMiscellaneous.DirectDampingByFrequency.DirectDampingByFrequency` object.
    directDampingByFrequency: DirectDampingByFrequency = DirectDampingByFrequency()

    #: A :py:class:`~abaqus.StepMiscellaneous.RayleighDampingByFrequency.RayleighDampingByFrequency` object.
    rayleighDampingByFrequency: RayleighDampingByFrequency = (
        RayleighDampingByFrequency()
    )

    #: A :py:class:`~abaqus.StepMiscellaneous.StructuralDampingByFrequency.StructuralDampingByFrequency` object.
    structuralDampingByFrequency: StructuralDampingByFrequency = (
        StructuralDampingByFrequency()
    )

    #: A SymbolicConstant specifying whether the step has an explicit procedure type
    #: (*procedureType*=ANNEAL, DYNAMIC_EXPLICIT, or DYNAMIC_TEMP_DISPLACEMENT).
    explicit: SymbolicConstant = None

    #: A Boolean specifying whether the step has a perturbation procedure type.
    perturbation: Boolean = OFF

    #: A Boolean specifying whether the step has a mechanical procedure type.
    nonmechanical: Boolean = OFF

    #: A SymbolicConstant specifying the Abaqus procedure. Possible values are:
    #: 
    #: - ANNEAL
    #: - BUCKLE
    #: - COMPLEX_FREQUENCY
    #: - COUPLED_TEMP_DISPLACEMENT
    #: - COUPLED_THERMAL_ELECTRIC
    #: - DIRECT_CYCLIC
    #: - DYNAMIC_IMPLICIT
    #: - DYNAMIC_EXPLICIT
    #: - DYNAMIC_SUBSPACE
    #: - DYNAMIC_TEMP_DISPLACEMENT
    #: - COUPLED_THERMAL_ELECTRICAL_STRUCTURAL
    #: - FREQUENCY
    #: - GEOSTATIC
    #: - HEAT_TRANSFER
    #: - MASS_DIFFUSION
    #: - MODAL_DYNAMICS
    #: - RANDOM_RESPONSE
    #: - RESPONSE_SPECTRUM
    #: - SOILS
    #: - STATIC_GENERAL
    #: - STATIC_LINEAR_PERTURBATION
    #: - STATIC_RIKS
    #: - STEADY_STATE_DIRECT
    #: - STEADY_STATE_MODAL
    #: - STEADY_STATE_SUBSPACE
    #: - VISCO
    procedureType: SymbolicConstant = None

    #: A Boolean specifying whether the step is suppressed or not. The default value is OFF.
    suppressed: Boolean = OFF

    #: A repository of FieldOutputRequestState objects.
    fieldOutputRequestState: typing.Dict[str, FieldOutputRequestState] = {}

    #: A repository of HistoryOutputRequestState objects.
    historyOutputRequestState: typing.Dict[str, HistoryOutputRequestState] = {}

    #: A :py:class:`~abaqus.StepOutput.DiagnosticPrint.DiagnosticPrint` object.
    diagnosticPrint: DiagnosticPrint = DiagnosticPrint()

    #: A :py:class:`~abaqus.StepOutput.Monitor.Monitor` object.
    monitor: Monitor = None

    #: A :py:class:`~abaqus.StepOutput.Restart.Restart` object.
    restart: Restart = Restart()

    #: A repository of AdaptiveMeshConstraintState objects.
    adaptiveMeshConstraintStates: typing.Dict[str, AdaptiveMeshConstraintState] = {}

    #: A repository of AdaptiveMeshDomain objects.
    adaptiveMeshDomains: typing.Dict[str, AdaptiveMeshDomain] = {}

    #: A :py:class:`~abaqus.StepMiscellaneous.Control.Control` object.
    control: Control = Control()

    #: A :py:class:`~abaqus.StepMiscellaneous.SolverControl.SolverControl` object.
    solverControl: SolverControl = SolverControl()

    #: A repository of BoundaryConditionState objects.
    boundaryConditionStates: typing.Dict[str, BoundaryConditionState] = {}

    #: A repository of InteractionState objects.
    interactionStates: int = None

    #: A repository of LoadState objects.
    loadStates: typing.Dict[str, LoadState] = {}

    #: A repository of LoadCase objects.
    loadCases: typing.Dict[str, LoadCase] = {}

    #: A repository of PredefinedFieldState objects.
    predefinedFieldStates: typing.Dict[str, PredefinedFieldState] = {}

    def __init__(
        self,
        name: str,
        previous: str,
        freq: RandomResponseFrequencyArray,
        description: str = "",
        scale: SymbolicConstant = LOG,
        directDamping: DirectDamping = None, 
        compositeDamping: CompositeDamping = None, 
        rayleighDamping: RayleighDamping = None, 
        structuralDamping: StructuralDamping = None, 
        directDampingByFrequency: DirectDampingByFrequency = None, 
        rayleighDampingByFrequency: RayleighDampingByFrequency = None, 
        structuralDampingByFrequency: StructuralDampingByFrequency = None, 
        maintainAttributes: Boolean = False,
    ):
        """This method creates a RandomResponseStep object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].RandomResponseStep

        Parameters
        ----------
        name
            A String specifying the repository key.
        previous
            A String specifying the name of the previous step. The new step appears after this step
            in the list of analysis steps.
        freq
            A :py:class:`~abaqus.StepMiscellaneous.RandomResponseFrequencyArray.RandomResponseFrequencyArray` object specifying frequencies over ranges of modes.
        description
            A String specifying a description of the new step. The default value is an empty string.
        scale
            A SymbolicConstant specifying the frequency scale. Possible values are LINEAR and LOG.
            The default value is LOG.
        directDamping
            A :py:class:`~abaqus.StepMiscellaneous.DirectDamping.DirectDamping` object.
        compositeDamping
            A :py:class:`~abaqus.StepMiscellaneous.CompositeDamping.CompositeDamping` object.
        rayleighDamping
            A :py:class:`~abaqus.StepMiscellaneous.RayleighDamping.RayleighDamping` object.
        structuralDamping
            A :py:class:`~abaqus.StepMiscellaneous.StructuralDamping.StructuralDamping` object.
        directDampingByFrequency
            A :py:class:`~abaqus.StepMiscellaneous.DirectDampingByFrequency.DirectDampingByFrequency` object.
        rayleighDampingByFrequency
            A :py:class:`~abaqus.StepMiscellaneous.RayleighDampingByFrequency.RayleighDampingByFrequency` object.
        structuralDampingByFrequency
            A :py:class:`~abaqus.StepMiscellaneous.StructuralDampingByFrequency.StructuralDampingByFrequency` object.
        maintainAttributes
            A Boolean specifying whether to retain attributes from an existing step with the same
            name. The default value is False.

        Returns
        -------
        RandomResponseStep
            A :py:class:`~abaqus.Step.RandomResponseStep.RandomResponseStep` object.

        Raises
        ------
        RangeError
        """
        super().__init__()

    def setValues(
        self,
        description: str = "",
        scale: SymbolicConstant = LOG,
        directDamping: DirectDamping = None, 
        compositeDamping: CompositeDamping = None, 
        rayleighDamping: RayleighDamping = None, 
        structuralDamping: StructuralDamping = None, 
        directDampingByFrequency: DirectDampingByFrequency = None, 
        rayleighDampingByFrequency: RayleighDampingByFrequency = None, 
        structuralDampingByFrequency: StructuralDampingByFrequency = None, 
    ):
        """This method modifies the RandomResponseStep object.

        Parameters
        ----------
        description
            A String specifying a description of the new step. The default value is an empty string.
        scale
            A SymbolicConstant specifying the frequency scale. Possible values are LINEAR and LOG.
            The default value is LOG.
        directDamping
            A :py:class:`~abaqus.StepMiscellaneous.DirectDamping.DirectDamping` object.
        compositeDamping
            A :py:class:`~abaqus.StepMiscellaneous.CompositeDamping.CompositeDamping` object.
        rayleighDamping
            A :py:class:`~abaqus.StepMiscellaneous.RayleighDamping.RayleighDamping` object.
        structuralDamping
            A :py:class:`~abaqus.StepMiscellaneous.StructuralDamping.StructuralDamping` object.
        directDampingByFrequency
            A :py:class:`~abaqus.StepMiscellaneous.DirectDampingByFrequency.DirectDampingByFrequency` object.
        rayleighDampingByFrequency
            A :py:class:`~abaqus.StepMiscellaneous.RayleighDampingByFrequency.RayleighDampingByFrequency` object.
        structuralDampingByFrequency
            A :py:class:`~abaqus.StepMiscellaneous.StructuralDampingByFrequency.StructuralDampingByFrequency` object.

        Raises
        ------
        RangeError
        """
        ...



from .CastIronCompressionHardening import CastIronCompressionHardening
from .CastIronTensionHardening import CastIronTensionHardening
from .....UtilityAndView.abaqusConstants import *


class CastIronPlasticity:
    r"""The CastIronPlasticity object specifies the Cast Iron plasticity model.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].castIronPlasticity
            import odbMaterial
            session.odbs[name].materials[name].castIronPlasticity

        The table data for this object are:

        - Plastic Poisson's ratio, :math:`\nu_{pl}` (dimensionless).
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - CAST IRON PLASTICITY
    """

    #: A :py:class:`~abaqus.Material.Plastic.Metal.CastIron.CastIronTensionHardening.CastIronTensionHardening` object.
    castIronTensionHardening: CastIronTensionHardening = CastIronTensionHardening(((),))

    #: A :py:class:`~abaqus.Material.Plastic.Metal.CastIron.CastIronCompressionHardening.CastIronCompressionHardening` object.
    castIronCompressionHardening: CastIronCompressionHardening = (
        CastIronCompressionHardening(((),))
    )

    def __init__(
        self, table: tuple, temperatureDependency: Boolean = OFF, dependencies: int = 0
    ):
        """This method creates a CastIronPlasticity object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].CastIronPlasticity
                session.odbs[name].materials[name].CastIronPlasticity

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        CastIronPlasticity
            A :py:class:`~abaqus.Material.Plastic.Metal.CastIron.CastIronPlasticity.CastIronPlasticity` object.

        Raises
        ------
        RangeError
        """
        ...

    def setValues(self, *args, **kwargs):
        """This method modifies the CastIronPlasticity object.

        Raises
        ------
        RangeError
        """
        ...



from .Profile import Profile


class CircularProfile(Profile):
    """The CircularProfile object defines the properties of a solid circular profile.
    The CircularProfile object is derived from the Profile object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].profiles[name]
            import odbSection
            session.odbs[name].profiles[name]

        The corresponding analysis keywords are:

        - BEAM SECTION
    """

    #: A String specifying the repository key.
    name: str

    #: A positive Float specifying the **r** dimension (outer radius) of the circular profile.
    #: For more information, see [Beam cross-section
    #: library](https://help.3ds.com/2021/English/DSSIMULIA_Established/SIMACAEELMRefMap/simaelm-c-beamcrosssectlib.htm?ContextScope=all).
    r: float

    def __init__(self, name: str, r: float):
        """This method creates a CircularProfile object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].CircularProfile
                session.odbs[name].CircularProfile

        Parameters
        ----------
        name
            A String specifying the repository key.
        r
            A positive Float specifying the **r** dimension (outer radius) of the circular profile.
            For more information, see [Beam cross-section
            library](https://help.3ds.com/2021/English/DSSIMULIA_Established/SIMACAEELMRefMap/simaelm-c-beamcrosssectlib.htm?ContextScope=all).

        Returns
        -------
        CircularProfile
            A :py:class:`~abaqus.BeamSectionProfile.CircularProfile.CircularProfile` object.

        Raises
        ------
        RangeError

        """
        super().__init__()

    def setValues(self, *args, **kwargs):
        """This method modifies the CircularProfile object.

        Raises
        ------
        RangeError

        """
        ...



import typing

from ..UtilityAndView.abaqusConstants import *
from .._OptionsBase import _CopyOptionsBase


class MovieOptions(_CopyOptionsBase):
    """The MovieOptions object stores settings that control how the movie background for an
    animation is rendered in a particular viewport. MovieOptions objects are accessed from
    the movie options associated with a particular viewport.
    The MovieOptions object has no constructor; Abaqus creates the **movieOptions** member for
    a viewport when the viewport is created using the values in the **movieOptions** member of
    the current viewport.

    Notes
    -----
    This object can be accessed by:

    .. code-block::

        session.viewports[name].movieOptions
    """
    #: A String specifying the name of the movie. A list of valid movie names is in the
    #: **movies** repository in the **session** object.
    movieName: str = ""

    #: A Boolean specifying whether a movie should be displayed in the viewport during an
    #: animation. The default value is OFF.
    showMovie: Boolean = OFF

    #: A SymbolicConstant specifying which positioning method is used to determine how the
    #: image will be scaled and positioned in the viewport. Possible values are:
    #:
    #: - FIT_TO_VIEWPORT, specifying a display mode where the image is scaled to fit in the
    #:   viewport using the specified **fitMethod**.
    #: - AUTO_ALIGN, specifying a display mode where the
    #:   image is scaled as specified by **xScale** and **yScale** and then positioned in the
    #:   viewport using the specified **alignment**.
    #: - MANUAL, specifying a display mode where the
    #:   image is scaled as specified by **xScale** and **yScale** and then positioned in the
    #:   viewport using the specified **origin**.
    #:
    #: The default value is FIT_TO_VIEWPORT.
    positionMethod: SymbolicConstant = FIT_TO_VIEWPORT

    #: A SymbolicConstant specifying which type of fit is performed to scale and position the
    #: image in the viewport. Possible values are:
    #:
    #: - BEST_FIT, specifying a mode where the image is scaled to completely fit within the
    #:   viewport.
    #: - FIT_WIDTH, specifying a mode where the image width is scaled to match the
    #:   viewport width.
    #: - FIT_HEIGHT, specifying a mode where the image height is scaled to match
    #:   the viewport height.
    #:
    #: The default value is BEST_FIT.
    fitMethod: SymbolicConstant = BEST_FIT

    #: A SymbolicConstant specifying the relative position of the image in the viewport when
    #: **positionMethod** =AUTO_ALIGN. Possible values are:
    #: 
    #: - BOTTOM_LEFT
    #: - BOTTOM_CENTER
    #: - BOTTOM_RIGHT
    #: - CENTER_LEFT
    #: - CENTER
    #: - CENTER_RIGHT
    #: - TOP_LEFT
    #: - TOP_CENTER
    #: - TOP_RIGHT
    #:
    #: The default value is CENTER.
    alignment: SymbolicConstant = CENTER

    #: A Float specifying the scale applied to the image width. The **xScale** argument is
    #: ignored when **positionMethod** =FIT_TO_VIEWPORT. The default value is 1.0.When **xScale**
    #: is negative, the image is mirrored about its y-axis but its position is not affected.
    xScale: float = 1.0

    #: A Float specifying the scale applied to the image height. The **yScale** argument is
    #: ignored when **positionMethod** =FIT_TO_VIEWPORT. The default value is 1.0.When **yScale**
    #: is negative, the image is mirrored about its x-axis but its position is not affected.
    yScale: float = 1.0

    #: A pair of Floats specifying the **X**- and **Y**-offsets in millimeters from the lower-left
    #: corner of the viewport. The **origin** argument is ignored unless **positionMethod**
    #: =MANUAL. The default value is (0, 0).
    origin: typing.Tuple[float, ...] = (0.0, 0.0)

    #: A Float specifying the translucency factor to use when displaying the image. Possible
    #: values are 0.0 ≤ **translucency** ≤ 1.0 with 0.0 being invisible and 1.0 being opaque.
    #: The default value is 1.0.
    translucency: float = 1.0

    def setValues(
        self,
        movieName: str = "",
        showMovie: Boolean = OFF,
        positionMethod: SymbolicConstant = FIT_TO_VIEWPORT,
        fitMethod: SymbolicConstant = BEST_FIT,
        alignment: SymbolicConstant = CENTER,
        xScale: float = 1.0,
        yScale: float = 1.0,
        origin: typing.Tuple[float, ...] = (0.0, 0.0),
        translucency: float = 1.0,
        options: str = None,
    ):
        """This method modifies the MovieOptions object.

        Parameters
        ----------
        movieName
            A String specifying the name of the movie. A list of valid movie names is in the
            **movies** repository in the **session** object.
        showMovie
            A Boolean specifying whether a movie should be displayed in the viewport during an
            animation. The default value is OFF.
        positionMethod
            A SymbolicConstant specifying which positioning method is used to determine how the
            image will be scaled and positioned in the viewport. Possible values are:

            - FIT_TO_VIEWPORT, specifying a display mode where the image is scaled to fit in the
              viewport using the specified **fitMethod**.
            - AUTO_ALIGN, specifying a display mode where the
              image is scaled as specified by **xScale** and **yScale** and then positioned in the
              viewport using the specified **alignment**.
            - MANUAL, specifying a display mode where the
              image is scaled as specified by **xScale** and **yScale** and then positioned in the
              viewport using the specified **origin**.

            The default value is FIT_TO_VIEWPORT.
        fitMethod
            A SymbolicConstant specifying which type of fit is performed to scale and position the
            image in the viewport when **positionMethod** =FIT_TO_VIEWPORT. Possible values are:

            - BEST_FIT, specifying a mode where the image is scaled to completely fit within the
              viewport.
            - FIT_WIDTH, specifying a mode where the image width is scaled to match the
              viewport width.
            - FIT_HEIGHT, specifying a mode where the image height is scaled to match
              the viewport height.

            The default value is BEST_FIT.
        alignment
            A SymbolicConstant specifying the relative position of the image in the viewport when
            **positionMethod** =AUTO_ALIGN. Possible values are:

            - BOTTOM_LEFT
            - BOTTOM_CENTER
            - BOTTOM_RIGHT
            - CENTER_LEFT
            - CENTER
            - CENTER_RIGHT
            - TOP_LEFT
            - TOP_CENTER
            - TOP_RIGHT

            The default value is CENTER.
        xScale
            A Float specifying the scale applied to the movie frame width. The **xScale** argument is
            ignored when **positionMethod** =FIT_TO_VIEWPORT. The default value is 1.0.When **xScale**
            is negative, the movie frame is mirrored about its y-axis but its position is not
            affected.
        yScale
            A Float specifying the scale applied to the movie frame height. The **yScale** argument is
            ignored when **positionMethod** =FIT_TO_VIEWPORT. The default value is 1.0.When **yScale**
            is negative, the movie frame is mirrored about its x-axis but its position is not
            affected.
        origin
            A pair of Floats specifying the*X*- and **Y**-offsets in millimeters from the lower-left
            corner of the viewport. The **origin** argument is ignored unless **positionMethod**
            =MANUAL. The default value is (0, 0).
        translucency
            A Float specifying the translucency factor to use when displaying the movie frame.
            Possible values are 0.0 ≤≤ **translucency** ≤≤ 1.0 with 0.0 being invisible and 1.0 being
            opaque. The default value is 1.0.
        options
            None or a MovieOptions object specifying the object from which values are to be copied.
            If other arguments are also supplied to setValues, they will override the values in the
            **options** member. The default value is None.

        Raises
        ------
        RangeError
        """
        super().setValues(
            options=options,
            movieName=movieName,
            showMovie=showMovie,
            positionMethod=positionMethod,
            fitMethod=fitMethod,
            alignment=alignment,
            xScale=xScale,
            yScale=yScale,
            origin=origin,
            translucency=translucency,
        )



from ...UtilityAndView.abaqusConstants import *


class BiaxialTestData:
    """The BiaxialTestData object provides equibiaxial test data (compression and/or tension).

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].hyperelastic.biaxialTestData
            mdb.models[name].materials[name].hyperfoam.biaxialTestData
            mdb.models[name].materials[name].mullinsEffect.biaxialTests[i]
            import odbMaterial
            session.odbs[name].materials[name].hyperelastic.biaxialTestData
            session.odbs[name].materials[name].hyperfoam.biaxialTestData
            session.odbs[name].materials[name].mullinsEffect.biaxialTests[i]

        The corresponding analysis keywords are:

        - BIAXIAL TEST DATA
    """

    def __init__(
        self,
        table: tuple,
        smoothing: int = None,
        lateralNominalStrain: Boolean = OFF,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a BiaxialTestData object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].hyperelastic.BiaxialTestData
                mdb.models[name].materials[name].hyperfoam.BiaxialTestData
                mdb.models[name].materials[name].mullinsEffect.BiaxialTestData
                session.odbs[name].materials[name].hyperelastic.BiaxialTestData
                session.odbs[name].materials[name].hyperfoam.BiaxialTestData
                session.odbs[name].materials[name].mullinsEffect.BiaxialTestData

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the following:
            
            - Nominal stress, TB.
            - Nominal strain, ϵB.
        smoothing
            None or an Int specifying the value for smoothing. If **smoothing** = None, no smoothing is
            employed. The default value is None.
        lateralNominalStrain
            A Boolean specifying whether to include lateral nominal strain. The default value is
            OFF.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        BiaxialTestData
            A :py:class:`~abaqus.Material.TestData.BiaxialTestData.BiaxialTestData` object.
        """
        ...

    def setValues(self, *args, **kwargs):
        """This method modifies the BiaxialTestData object."""
        ...



import typing

from ..UtilityAndView.abaqusConstants import *


class CaeKerPrefs:
    """The CaeKerPrefs object contains the details of the sessionOptions.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import caePrefsAccess
            caePrefsAccess.openSessionOptions(...)
    """

    #: A String specifying the path to the preferences file that the CaeKerPrefs object
    #: represents.
    fileName: str = ""

    def save(self, backupFile: Boolean = OFF):
        """This method saves the sessionOptions in the current **fileName**.

        Parameters
        ----------
        backupFile: Boolean
            A Boolean specifying whether save a numbered backup copy of the preferences file,
            **fileName**. Default is True.
        """
        # TODO: Implement this method
        ...
    
    def saveAs(self, fileName: str = '', directory: typing.Literal["CURRENT", "HOME"] = HOME):
        """This method saves the sessionOptions to the specified location.

        Parameters
        ----------
        fileName: str
            A String specifying the path to the preferences file.
        directory: SymbolicConstant
            A SymbolicConstant specifying the location of the preferences file. Possible values
            are:

            - CURRENT to open the preferences file in the current directory 
              (caePrefsAccess.CURRENT)
            - HOME to open the preferences file in your home directory 
              (caePrefsAccess.HOME)
            
            The default value is HOME. Either **fileName** or **directory** must be
            supplied. The **fileName** or **directory** arguments are mutually exclusive.
        """
        # TODO: Implement this method
        ...



from .Interaction import Interaction
from ..BasicGeometry.ModelDot import ModelDot
from ..Region.RegionArray import RegionArray
from ..UtilityAndView.abaqusConstants import *


class CavityRadiation(Interaction):
    """The CavityRadiation object defines cavities for thermal radiation heat transfer and
    controls the calculation of viewfactors.
    The CavityRadiation object is derived from the Interaction object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactions[name]

        The corresponding analysis keywords are:

        - CAVITY DEFINITION
                - CYCLIC
                - EMISSIVITY
                - PERIODIC
                - RADIATION SYMMETRY
                - RADIATION VIEWFACTOR
                - REFLECTION
    """

    #: A String specifying the repository key.
    name: str = ""

    #: None or a Float specifying the reference ambient temperature value, θ0θ0. Specifying a
    #: value indicates an open cavity. The default value is None.
    ambientTemp: float = None

    #: A Float specifying the facet area ratio above which the infinitesimal-to-finite area
    #: approximation is used for viewfactor calculations. The default value is 64.0.
    minInfinitesimalRatio: float = 64

    #: An Int specifying the number of Gauss integration points to be used along each edge when
    #: the numerical integration of contour integrals is used for viewfactor calculations. One
    #: to five integration points are allowed. The default value is 3.
    numPointsPerEdge: int = 3

    #: A Float specifying the nondimensional distance-square value above which the lumped area
    #: approximation is used for viewfactor calculations. The default value is 5.0.
    minLumpedAreaDS: float = 5

    #: A Boolean specifying whether cyclic symmetry will be applied. This argument cannot be
    #: specified for axisymmetric models. The default value is OFF.
    cyclicSymmetry: Boolean = OFF

    #: An Int specifying the number of cyclically similar images that compose the cavity formed
    #: as a result of this symmetry. This argument applies only when **cyclicSymmetry** = ON. The
    #: default value is 2.
    cyclicImages: int = 2

    #: An Int specifying the number of periodic symmetries that will be applied. The default
    #: value is 0.
    periodicSymmetries: int = 0

    #: An Int specifying the number of repetitions used in the numerical calculation of the
    #: cavity viewfactors resulting from the first periodic symmetry. The result of this
    #: symmetry is a cavity composed of the cavity surface defined in the model plus twice the
    #: value of **periodicImages_1**. This argument applies only when **periodicSymmetries** is
    #: greater than zero. The default value is 2.
    periodicImages_1: int = 2

    #: An Int specifying the number of repetitions used in the numerical calculation of the
    #: cavity viewfactors resulting from the second periodic symmetry. The result of this
    #: symmetry is a cavity composed of the cavity surface defined in the model plus twice the
    #: value of **periodicImages_2**. This argument applies only when **periodicSymmetries** is
    #: greater than one. The default value is 2.
    periodicImages_2: int = 2

    #: An Int specifying the number of repetitions used in the numerical calculation of the
    #: cavity viewfactors resulting from the third periodic symmetry. The result of this
    #: symmetry is a cavity composed of the cavity surface defined in the model plus twice the
    #: value of **periodicImages_3**. This argument applies only when **periodicSymmetries** = 3.
    #: The default value is 2.
    periodicImages_3: int = 2

    #: None or a Float specifying the Z value indicating the symmetry reference line in
    #: axisymmetric models. This argument applies only for axisymmetric models, and when
    #: **periodicSymmetries** = 1. The default value is None.
    periodicSymZ: float = None

    #: None or a Float specifying the Z value indicating the periodic distance in axisymmetric
    #: models. This argument applies only for axisymmetric models, and when
    #: **periodicSymmetries** = 1. The default value is None.
    periodicDistZ: float = None

    #: An Int specifying the number of reflection symmetries will be applied. The default value
    #: is 0.
    reflectionSymmetries: int = 0

    #: None or a Float specifying the Z value indicating the symmetry reference line in
    #: axisymmetric models. This argument applies only for axisymmetric models, and when
    #: **reflectionSymmetries** = 1. The default value is None.
    reflectionSymZ: float = None

    #: A String specifying the name of the step in which the cavity radiation interaction
    #: should be created.
    createStepName: str = ""

    #: A :py:class:`~abaqus.Region.RegionArray.RegionArray` object specifying the surfaces for which radiation viewfactor control is
    #: being specified.
    surfaces: RegionArray = []

    #: A tuple of Strings specifying the names of the Cavity Radiation properties containing
    #: the surface emissivity data. One name per specified surface. The emissivity data is
    #: ignored when **surfaceReflection** = OFF.
    surfaceEmissivities: tuple = ()

    #: A :py:class:`~abaqus.BasicGeometry.ModelDot.ModelDot` object specifying the rotation axis point. This argument applies only when
    #: **cyclicSymmetry** = ON.
    cyclicRotPt: ModelDot = ModelDot()

    #: A :py:class:`~abaqus.BasicGeometry.ModelDot.ModelDot` object specifying the rotation axis end point. This argument applies only for
    #: three-dimensional models, and only when **cyclicSymmetry** = ON.
    cyclicRotEndPt: ModelDot = ModelDot()

    #: A :py:class:`~abaqus.BasicGeometry.ModelDot.ModelDot` object specifying the symmetry axis end point. This argument applies only
    #: when **cyclicSymmetry** = ON.
    cyclicSymPt: ModelDot = ModelDot()

    #: A tuple of tuples of Floats specifying the two points of the vector that describes the
    #: periodic distance for the first periodic symmetry. Each point is defined by a tuple of
    #: three coordinates indicating its position. This argument applies only when
    #: **periodicSymmetries** is greater than zero. The default value is an empty sequence.
    periodicDistance_1: tuple = ()

    #: A tuple of tuples of Floats specifying the two points of the vector that describes the
    #: periodic distance for the second periodic symmetry. Each point is defined by a tuple of
    #: three coordinates indicating its position. This argument applies only when
    #: **periodicSymmetries** is greater than one. The default value is an empty sequence.
    periodicDistance_2: tuple = ()

    #: A tuple of tuples of Floats specifying the two points of the vector that describes the
    #: periodic distance for the third periodic symmetry. Each point is defined by a tuple of
    #: three coordinates indicating its position. This argument applies only when
    #: **periodicSymmetries** = 3. The default value is an empty sequence.
    periodicDistance_3: tuple = ()

    def __init__(
        self,
        name: str,
        createStepName: str,
        surfaces: RegionArray,
        surfaceEmissivities: tuple,
        ambientTemp: float = None,
        blocking: SymbolicConstant = BLOCKING_ALL,
        blockingSurfaces: RegionArray = None,
        rangeOfView: float = None,
        surfaceReflection: Boolean = ON,
        viewfactorAccurTol: float = 0,
        minInfinitesimalRatio: float = 64,
        numPointsPerEdge: int = 3,
        minLumpedAreaDS: float = 5,
        cyclicSymmetry: Boolean = OFF,
        cyclicImages: int = 2,
        cyclicRotPt: ModelDot = None, 
        cyclicRotEndPt: ModelDot = None, 
        cyclicSymPt: ModelDot = None, 
        periodicSymmetries: int = 0,
        periodicImages_1: int = 2,
        periodicImages_2: int = 2,
        periodicImages_3: int = 2,
        periodicSymAxis_1: str = "",
        periodicSymAxis_2: str = "",
        periodicSymPlane_1: str = "",
        periodicSymPlane_2: str = "",
        periodicSymPlane_3: str = "",
        periodicDistance_1: tuple = (),
        periodicDistance_2: tuple = (),
        periodicDistance_3: tuple = (),
        periodicSymZ: float = None,
        periodicDistZ: float = None,
        reflectionSymmetries: int = 0,
        reflectionSymAxis_1: str = "",
        reflectionSymAxis_2: str = "",
        reflectionSymPlane_1: str = "",
        reflectionSymPlane_2: str = "",
        reflectionSymPlane_3: str = "",
        reflectionSymZ: float = None,
    ):
        """This method creates a CavityRadiation object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].CavityRadiation

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the cavity radiation interaction
            should be created.
        surfaces
            A :py:class:`~abaqus.Region.RegionArray.RegionArray` object specifying the surfaces for which radiation viewfactor control is
            being specified.
        surfaceEmissivities
            A sequence of Strings specifying the names of the Cavity Radiation properties containing
            the surface emissivity data. One name per specified surface. The emissivity data is
            ignored when **surfaceReflection** = OFF.
        ambientTemp
            None or a Float specifying the reference ambient temperature value, θ0θ0. Specifying a
            value indicates an open cavity. The default value is None.
        blocking
            A SymbolicConstant specifying the blocking checks to be performed in the viewfactor
            calculations. Possible values are BLOCKING_ALL, NO_BLOCKING, and PARTIAL_BLOCKING. The
            default value is BLOCKING_ALL.
        blockingSurfaces
            A :py:class:`~abaqus.Region.RegionArray.RegionArray` object specifying the surfaces that provide blocking inside the cavity.
            This argument applies only when **blocking** = PARTIAL_BLOCKING.
        rangeOfView
            None or a Float specifying the maximum distance between surface facets at which
            viewfactors are calculated. More distant facets are deemed too far apart to exchange
            significant amounts of heat through radiation effects, and the viewfactors between these
            facets are assumed to be zero. If **rangeOfView** = None, there is no upper limit. The
            default value is None.
        surfaceReflection
            A Boolean specifying whether heat reflections are to be included in the cavity radiation
            calculations. The default value is ON.
        viewfactorAccurTol
            A Float specifying the acceptable tolerance for the viewfactor calculations. The default
            value is 0.05.
        minInfinitesimalRatio
            A Float specifying the facet area ratio above which the infinitesimal-to-finite area
            approximation is used for viewfactor calculations. The default value is 64.0.
        numPointsPerEdge
            An Int specifying the number of Gauss integration points to be used along each edge when
            the numerical integration of contour integrals is used for viewfactor calculations. One
            to five integration points are allowed. The default value is 3.
        minLumpedAreaDS
            A Float specifying the nondimensional distance-square value above which the lumped area
            approximation is used for viewfactor calculations. The default value is 5.0.
        cyclicSymmetry
            A Boolean specifying whether cyclic symmetry will be applied. This argument cannot be
            specified for axisymmetric models. The default value is OFF.
        cyclicImages
            An Int specifying the number of cyclically similar images that compose the cavity formed
            as a result of this symmetry. This argument applies only when **cyclicSymmetry** = ON. The
            default value is 2.
        cyclicRotPt
            A :py:class:`~abaqus.BasicGeometry.ModelDot.ModelDot` object specifying the rotation axis point. This argument applies only when
            **cyclicSymmetry** = ON.
        cyclicRotEndPt
            A :py:class:`~abaqus.BasicGeometry.ModelDot.ModelDot` object specifying the rotation axis end point. This argument applies only for
            three-dimensional models, and only when **cyclicSymmetry** = ON.
        cyclicSymPt
            A :py:class:`~abaqus.BasicGeometry.ModelDot.ModelDot` object specifying the symmetry axis end point. This argument applies only
            when **cyclicSymmetry** = ON.
        periodicSymmetries
            An Int specifying the number of periodic symmetries that will be applied. The default
            value is 0.
        periodicImages_1
            An Int specifying the number of repetitions used in the numerical calculation of the
            cavity viewfactors resulting from the first periodic symmetry. The result of this
            symmetry is a cavity composed of the cavity surface defined in the model plus twice the
            value of **periodicImages_1**. This argument applies only when **periodicSymmetries** is
            greater than zero. The default value is 2.
        periodicImages_2
            An Int specifying the number of repetitions used in the numerical calculation of the
            cavity viewfactors resulting from the second periodic symmetry. The result of this
            symmetry is a cavity composed of the cavity surface defined in the model plus twice the
            value of **periodicImages_2**. This argument applies only when **periodicSymmetries** is
            greater than one. The default value is 2.
        periodicImages_3
            An Int specifying the number of repetitions used in the numerical calculation of the
            cavity viewfactors resulting from the third periodic symmetry. The result of this
            symmetry is a cavity composed of the cavity surface defined in the model plus twice the
            value of **periodicImages_3**. This argument applies only when **periodicSymmetries** = 3.
            The default value is 2.
        periodicSymAxis_1
            A straight Edge, a Datum object representing a datum axis, or an ElementEdge object
            indicating the first line of symmetry in two-dimensional models. This argument applies
            only for 2D models, and when **periodicSymmetries** is greater than zero.
        periodicSymAxis_2
            A straight Edge, a Datum object representing a datum axis, or an ElementEdge object
            indicating the second line of symmetry in two-dimensional models. This argument applies
            only for two-dimensional models, and when **periodicSymmetries** = 2.
        periodicSymPlane_1
            A planar Face, an ElementFace, or a Datum object representing a datum plane; indicating
            the first plane of symmetry in three-dimensional models. This argument applies only for
            three-dimensional models, and when **periodicSymmetries** is greater than zero.
        periodicSymPlane_2
            A planar Face, an ElementFace, or a Datum object representing a datum plane; indicating
            the second plane of symmetry in three-dimensional models. This argument applies only for
            three-dimensional models, and when **periodicSymmetries** is greater than one.
        periodicSymPlane_3
            A planar Face, an ElementFace, or a Datum object representing a datum plane; indicating
            the third plane of symmetry in three-dimensional models. This argument applies only for
            three-dimensional models, and when **periodicSymmetries** = 3.
        periodicDistance_1
            A sequence of sequences of Floats specifying the two points of the vector that describes
            the periodic distance for the first periodic symmetry. Each point is defined by a tuple
            of three coordinates indicating its position. This argument applies only when
            **periodicSymmetries** is greater than zero. The default value is an empty sequence.
        periodicDistance_2
            A sequence of sequences of Floats specifying the two points of the vector that describes
            the periodic distance for the second periodic symmetry. Each point is defined by a tuple
            of three coordinates indicating its position. This argument applies only when
            **periodicSymmetries** is greater than one. The default value is an empty sequence.
        periodicDistance_3
            A sequence of sequences of Floats specifying the two points of the vector that describes
            the periodic distance for the third periodic symmetry. Each point is defined by a tuple
            of three coordinates indicating its position. This argument applies only when
            **periodicSymmetries** = 3. The default value is an empty sequence.
        periodicSymZ
            None or a Float specifying the Z value indicating the symmetry reference line in
            axisymmetric models. This argument applies only for axisymmetric models, and when
            **periodicSymmetries** = 1. The default value is None.
        periodicDistZ
            None or a Float specifying the Z value indicating the periodic distance in axisymmetric
            models. This argument applies only for axisymmetric models, and when
            **periodicSymmetries** = 1. The default value is None.
        reflectionSymmetries
            An Int specifying the number of reflection symmetries will be applied. The default value
            is 0.
        reflectionSymAxis_1
            A straight Edge, a Datum object representing a datum axis, or an ElementEdge object
            indicating the first line of symmetry in two-dimensional models. This argument applies
            only for two-dimensional models, and when **reflectionSymmetries** is greater than zero.
        reflectionSymAxis_2
            A straight Edge, a Datum object representing a datum axis, or an ElementEdge object
            indicating the second line of symmetry in two-dimensional models. This argument applies
            only for two-dimensional models, and when **reflectionSymmetries** = 2.
        reflectionSymPlane_1
            A planar Face, an ElementFace, or a Datum object representing a datum plane; indicating
            the first plane of symmetry in three-dimensional models. This argument applies only for
            three-dimensional models, and when **reflectionSymmetries** is greater than zero.
        reflectionSymPlane_2
            A planar Face, an ElementFace, or a Datum object representing a datum plane; indicating
            the second plane of symmetry in three-dimensional models. This argument applies only for
            three-dimensional models, and when **reflectionSymmetries** is greater than one.
        reflectionSymPlane_3
            A planar Face, an ElementFace, or a Datum object representing a datum plane; indicating
            the third plane of symmetry in three-dimensional models. This argument applies only for
            three-dimensional models, and when **reflectionSymmetries** = 3.
        reflectionSymZ
            None or a Float specifying the Z value indicating the symmetry reference line in
            axisymmetric models. This argument applies only for axisymmetric models, and when
            **reflectionSymmetries** = 1. The default value is None.

        Returns
        -------
        CavityRadiation
            A :py:class:`~abaqus.Interaction.CavityRadiation.CavityRadiation` object.
        """
        super().__init__()

    def setValues(
        self,
        surfaceEmissivities: tuple = (),
        ambientTemp: float = None,
        blocking: SymbolicConstant = BLOCKING_ALL,
        blockingSurfaces: RegionArray = None,
        rangeOfView: float = None,
        surfaceReflection: Boolean = ON,
        viewfactorAccurTol: float = 0,
        minInfinitesimalRatio: float = 64,
        numPointsPerEdge: int = 3,
        minLumpedAreaDS: float = 5,
        cyclicSymmetry: Boolean = OFF,
        cyclicImages: int = 2,
        cyclicRotPt: ModelDot = None, 
        cyclicRotEndPt: ModelDot = None, 
        cyclicSymPt: ModelDot = None, 
        periodicSymmetries: int = 0,
        periodicImages_1: int = 2,
        periodicImages_2: int = 2,
        periodicImages_3: int = 2,
        periodicSymAxis_1: str = "",
        periodicSymAxis_2: str = "",
        periodicSymPlane_1: str = "",
        periodicSymPlane_2: str = "",
        periodicSymPlane_3: str = "",
        periodicDistance_1: tuple = (),
        periodicDistance_2: tuple = (),
        periodicDistance_3: tuple = (),
        periodicSymZ: float = None,
        periodicDistZ: float = None,
        reflectionSymmetries: int = 0,
        reflectionSymAxis_1: str = "",
        reflectionSymAxis_2: str = "",
        reflectionSymPlane_1: str = "",
        reflectionSymPlane_2: str = "",
        reflectionSymPlane_3: str = "",
        reflectionSymZ: float = None,
    ):
        """This method modifies the data for an existing CavityRadiation object in the step where
        it is created.

        Parameters
        ----------
        surfaceEmissivities
            A sequence of Strings specifying the names of the Cavity Radiation properties containing
            the surface emissivity data. One name per specified surface. The emissivity data is
            ignored when **surfaceReflection** = OFF.
        ambientTemp
            None or a Float specifying the reference ambient temperature value, θ0θ0. Specifying a
            value indicates an open cavity. The default value is None.
        blocking
            A SymbolicConstant specifying the blocking checks to be performed in the viewfactor
            calculations. Possible values are BLOCKING_ALL, NO_BLOCKING, and PARTIAL_BLOCKING. The
            default value is BLOCKING_ALL.
        blockingSurfaces
            A :py:class:`~abaqus.Region.RegionArray.RegionArray` object specifying the surfaces that provide blocking inside the cavity.
            This argument applies only when **blocking** = PARTIAL_BLOCKING.
        rangeOfView
            None or a Float specifying the maximum distance between surface facets at which
            viewfactors are calculated. More distant facets are deemed too far apart to exchange
            significant amounts of heat through radiation effects, and the viewfactors between these
            facets are assumed to be zero. If **rangeOfView** = None, there is no upper limit. The
            default value is None.
        surfaceReflection
            A Boolean specifying whether heat reflections are to be included in the cavity radiation
            calculations. The default value is ON.
        viewfactorAccurTol
            A Float specifying the acceptable tolerance for the viewfactor calculations. The default
            value is 0.05.
        minInfinitesimalRatio
            A Float specifying the facet area ratio above which the infinitesimal-to-finite area
            approximation is used for viewfactor calculations. The default value is 64.0.
        numPointsPerEdge
            An Int specifying the number of Gauss integration points to be used along each edge when
            the numerical integration of contour integrals is used for viewfactor calculations. One
            to five integration points are allowed. The default value is 3.
        minLumpedAreaDS
            A Float specifying the nondimensional distance-square value above which the lumped area
            approximation is used for viewfactor calculations. The default value is 5.0.
        cyclicSymmetry
            A Boolean specifying whether cyclic symmetry will be applied. This argument cannot be
            specified for axisymmetric models. The default value is OFF.
        cyclicImages
            An Int specifying the number of cyclically similar images that compose the cavity formed
            as a result of this symmetry. This argument applies only when **cyclicSymmetry** = ON. The
            default value is 2.
        cyclicRotPt
            A :py:class:`~abaqus.BasicGeometry.ModelDot.ModelDot` object specifying the rotation axis point. This argument applies only when
            **cyclicSymmetry** = ON.
        cyclicRotEndPt
            A :py:class:`~abaqus.BasicGeometry.ModelDot.ModelDot` object specifying the rotation axis end point. This argument applies only for
            three-dimensional models, and only when **cyclicSymmetry** = ON.
        cyclicSymPt
            A :py:class:`~abaqus.BasicGeometry.ModelDot.ModelDot` object specifying the symmetry axis end point. This argument applies only
            when **cyclicSymmetry** = ON.
        periodicSymmetries
            An Int specifying the number of periodic symmetries that will be applied. The default
            value is 0.
        periodicImages_1
            An Int specifying the number of repetitions used in the numerical calculation of the
            cavity viewfactors resulting from the first periodic symmetry. The result of this
            symmetry is a cavity composed of the cavity surface defined in the model plus twice the
            value of **periodicImages_1**. This argument applies only when **periodicSymmetries** is
            greater than zero. The default value is 2.
        periodicImages_2
            An Int specifying the number of repetitions used in the numerical calculation of the
            cavity viewfactors resulting from the second periodic symmetry. The result of this
            symmetry is a cavity composed of the cavity surface defined in the model plus twice the
            value of **periodicImages_2**. This argument applies only when **periodicSymmetries** is
            greater than one. The default value is 2.
        periodicImages_3
            An Int specifying the number of repetitions used in the numerical calculation of the
            cavity viewfactors resulting from the third periodic symmetry. The result of this
            symmetry is a cavity composed of the cavity surface defined in the model plus twice the
            value of **periodicImages_3**. This argument applies only when **periodicSymmetries** = 3.
            The default value is 2.
        periodicSymAxis_1
            A straight Edge, a Datum object representing a datum axis, or an ElementEdge object
            indicating the first line of symmetry in two-dimensional models. This argument applies
            only for 2D models, and when **periodicSymmetries** is greater than zero.
        periodicSymAxis_2
            A straight Edge, a Datum object representing a datum axis, or an ElementEdge object
            indicating the second line of symmetry in two-dimensional models. This argument applies
            only for two-dimensional models, and when **periodicSymmetries** = 2.
        periodicSymPlane_1
            A planar Face, an ElementFace, or a Datum object representing a datum plane; indicating
            the first plane of symmetry in three-dimensional models. This argument applies only for
            three-dimensional models, and when **periodicSymmetries** is greater than zero.
        periodicSymPlane_2
            A planar Face, an ElementFace, or a Datum object representing a datum plane; indicating
            the second plane of symmetry in three-dimensional models. This argument applies only for
            three-dimensional models, and when **periodicSymmetries** is greater than one.
        periodicSymPlane_3
            A planar Face, an ElementFace, or a Datum object representing a datum plane; indicating
            the third plane of symmetry in three-dimensional models. This argument applies only for
            three-dimensional models, and when **periodicSymmetries** = 3.
        periodicDistance_1
            A sequence of sequences of Floats specifying the two points of the vector that describes
            the periodic distance for the first periodic symmetry. Each point is defined by a tuple
            of three coordinates indicating its position. This argument applies only when
            **periodicSymmetries** is greater than zero. The default value is an empty sequence.
        periodicDistance_2
            A sequence of sequences of Floats specifying the two points of the vector that describes
            the periodic distance for the second periodic symmetry. Each point is defined by a tuple
            of three coordinates indicating its position. This argument applies only when
            **periodicSymmetries** is greater than one. The default value is an empty sequence.
        periodicDistance_3
            A sequence of sequences of Floats specifying the two points of the vector that describes
            the periodic distance for the third periodic symmetry. Each point is defined by a tuple
            of three coordinates indicating its position. This argument applies only when
            **periodicSymmetries** = 3. The default value is an empty sequence.
        periodicSymZ
            None or a Float specifying the Z value indicating the symmetry reference line in
            axisymmetric models. This argument applies only for axisymmetric models, and when
            **periodicSymmetries** = 1. The default value is None.
        periodicDistZ
            None or a Float specifying the Z value indicating the periodic distance in axisymmetric
            models. This argument applies only for axisymmetric models, and when
            **periodicSymmetries** = 1. The default value is None.
        reflectionSymmetries
            An Int specifying the number of reflection symmetries will be applied. The default value
            is 0.
        reflectionSymAxis_1
            A straight Edge, a Datum object representing a datum axis, or an ElementEdge object
            indicating the first line of symmetry in two-dimensional models. This argument applies
            only for two-dimensional models, and when **reflectionSymmetries** is greater than zero.
        reflectionSymAxis_2
            A straight Edge, a Datum object representing a datum axis, or an ElementEdge object
            indicating the second line of symmetry in two-dimensional models. This argument applies
            only for two-dimensional models, and when **reflectionSymmetries** = 2.
        reflectionSymPlane_1
            A planar Face, an ElementFace, or a Datum object representing a datum plane; indicating
            the first plane of symmetry in three-dimensional models. This argument applies only for
            three-dimensional models, and when **reflectionSymmetries** is greater than zero.
        reflectionSymPlane_2
            A planar Face, an ElementFace, or a Datum object representing a datum plane; indicating
            the second plane of symmetry in three-dimensional models. This argument applies only for
            three-dimensional models, and when **reflectionSymmetries** is greater than one.
        reflectionSymPlane_3
            A planar Face, an ElementFace, or a Datum object representing a datum plane; indicating
            the third plane of symmetry in three-dimensional models. This argument applies only for
            three-dimensional models, and when **reflectionSymmetries** = 3.
        reflectionSymZ
            None or a Float specifying the Z value indicating the symmetry reference line in
            axisymmetric models. This argument applies only for axisymmetric models, and when
            **reflectionSymmetries** = 1. The default value is None.
        """
        ...

    def setValuesInStep(
        self,
        stepName: str,
        blocking: SymbolicConstant = BLOCKING_ALL,
        blockingSurfaces: RegionArray = None,
        rangeOfView: float = None,
        surfaceReflection: Boolean = ON,
        viewfactorAccurTol: float = 0,
    ):
        """This method modifies the propagating data of an existing CavityRadiation object in the
        specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the interaction is modified.
        blocking
            A SymbolicConstant specifying the blocking checks to be performed in the viewfactor
            calculations. Possible values are BLOCKING_ALL, NO_BLOCKING, and PARTIAL_BLOCKING. The
            default value is BLOCKING_ALL.
        blockingSurfaces
            A :py:class:`~abaqus.Region.RegionArray.RegionArray` object specifying the surfaces that provide blocking inside the cavity.
            This argument applies only when **blocking** = PARTIAL_BLOCKING.
        rangeOfView
            None or a Float specifying the maximum distance between surface facets at which
            viewfactors are calculated. More distant facets are deemed too far apart to exchange
            significant amounts of heat through radiation effects, and the viewfactors between these
            facets are assumed to be zero. If **rangeOfView** = None, there is no upper limit. The
            default value is None.
        surfaceReflection
            A Boolean specifying whether heat reflections are to be included in the cavity radiation
            calculations. The default value is ON.
        viewfactorAccurTol
            A Float specifying the acceptable tolerance for the viewfactor calculations. The default
            value is 0.05.
        """
        ...



from .Interaction import Interaction
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


class SelfContactExp(Interaction):
    """The SelfContactExp object defines self-contact during an Abaqus/Explicit analysis.
    The SelfContactExp object is derived from the Interaction object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactions[name]
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the step in which the SelfContactExp object is created.
    createStepName: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the surface where self-contact is defined.
    surface: Region

    #: A String specifying the name of the ContactProperty object associated with this
    #: interaction.
    interactionProperty: str

    #: A SymbolicConstant specifying the mechanical constraint formulation. Possible values are
    #: KINEMATIC and PENALTY. The default value is KINEMATIC.
    mechanicalConstraint: SymbolicConstant = KINEMATIC

    #: A String specifying the name of the ContactControl object associated with this
    #: interaction. An empty string indicates that the default contact controls will be used.
    #: The default value is an empty string.
    contactControls: str = ""

    def __init__(
        self,
        name: str,
        createStepName: str,
        surface: Region,
        interactionProperty: str,
        mechanicalConstraint: SymbolicConstant = KINEMATIC,
        contactControls: str = "",
    ):
        """This method creates a SelfContactExp object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].SelfContactExp

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the SelfContactExp object is created.
        surface
            A :py:class:`~abaqus.Region.Region.Region` object specifying the surface where self-contact is defined.
        interactionProperty
            A String specifying the name of the ContactProperty object associated with this
            interaction.
        mechanicalConstraint
            A SymbolicConstant specifying the mechanical constraint formulation. Possible values are
            KINEMATIC and PENALTY. The default value is KINEMATIC.
        contactControls
            A String specifying the name of the ContactControl object associated with this
            interaction. An empty string indicates that the default contact controls will be used.
            The default value is an empty string.

        Returns
        -------
        SelfContactExp
            A :py:class:`~abaqus.Interaction.SelfContactExp.SelfContactExp` object.
        """
        super().__init__()

    def setValues(
        self,
        mechanicalConstraint: SymbolicConstant = KINEMATIC,
        contactControls: str = "",
    ):
        """This method modifies the data for an existing SelfContactExp object in the step where it
        is created.

        Parameters
        ----------
        mechanicalConstraint
            A SymbolicConstant specifying the mechanical constraint formulation. Possible values are
            KINEMATIC and PENALTY. The default value is KINEMATIC.
        contactControls
            A String specifying the name of the ContactControl object associated with this
            interaction. An empty string indicates that the default contact controls will be used.
            The default value is an empty string.
        """
        ...

    def setValuesInStep(
        self, stepName: str, interactionProperty: str = "", contactControls: str = ""
    ):
        """This method modifies the propagating data for an existing SelfContactExp object in the
        specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the interaction is modified.
        interactionProperty
            A String specifying the name of the ContactProperty object associated with this
            interaction.
        contactControls
            A String specifying the name of the ContactControl object associated with this
            interaction. An empty string indicates that the default contact controls will be used.
            The default value is an empty string.
        """
        ...



from .GeometricRestriction import GeometricRestriction


class SizingClusterAreas(GeometricRestriction):
    """The SizingClusterAreas object defines a sizing cluster areas geometric restriction.
    The SizingClusterAreas object is derived from the GeometricRestriction object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import optimization
            mdb.models[name].optimizationTasks[name].geometricRestrictions[name]
    """

    #: A String specifying the geometric restriction repository key.
    name: str

    #: Tuple of Region objects specifying the regions to which the geometric restriction is
    #: applied.
    regions: tuple

    def __init__(self, name: str, regions: tuple):
        """This method creates a SizingClusterAreas object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].optimizationTasks[name].SizingClusterAreas

        Parameters
        ----------
        name
            A String specifying the geometric restriction repository key.
        regions
            Tuple of Region objects specifying the regions to which the geometric restriction is
            applied.

        Returns
        -------
        SizingClusterAreas
            A :py:class:`~abaqus.Optimization.SizingClusterAreas.SizingClusterAreas` object.
        """
        super().__init__()

    def setValues(self, *args, **kwargs):
        """This method modifies the SizingClusterAreas object."""
        ...



from .Leaf import Leaf
from ..UtilityAndView.abaqusConstants import *


class LeafFromNodeVarRange(Leaf):
    """The LeafFromNodeVarRange object can be used whenever a Leaf object is expected as an
    argument. Leaf objects are used to specify the items in a display group. Leaf objects
    are constructed as temporary objects, which are then used as arguments to DisplayGroup
    commands.
    The LeafFromNodeVarRange object is derived from the Leaf object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import displayGroupOdbToolset
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
    #: DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.
    leafType: SymbolicConstant = None

    #: A Float specifying the minimum value for the variable range. The default value is
    #: −3.40282346639E38.
    minimumRange: float = None

    #: A Float specifying the maximum value for the variable range. The default value is
    #: 3.40282346639e+038.
    maximumRange: float = 3

    #: A Boolean specifying the method used to evaluate the range. If **insideRange** = ON, the
    #: range falls inside the specified minimum and maximum values. The default value is ON.
    insideRange: Boolean = ON

    def __init__(
        self,
        minimumRange: float = None,
        maximumRange: float = 3,
        insideRange: Boolean = ON,
    ):
        """This method creates a Leaf object from nodes with values lying in a variable range.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                LeafFromNodeVarRange

        Parameters
        ----------
        minimumRange
            A Float specifying the minimum value for the variable range. The default value is
            −3.40282346639E38.
        maximumRange
            A Float specifying the maximum value for the variable range. The default value is
            3.40282346639e+038.
        insideRange
            A Boolean specifying the method used to evaluate the range. If **insideRange** = ON, the
            range falls inside the specified minimum and maximum values. The default value is ON.

        Returns
        -------
        LeafFromNodeVarRange
            A :py:class:`~abaqus.DisplayGroup.LeafFromNodeVarRange.LeafFromNodeVarRange` object.
        """
        super().__init__(DEFAULT_MODEL)



from .InteractionState import InteractionState
from ..UtilityAndView.abaqusConstants import *


class ElasticFoundationState(InteractionState):
    """The ElasticFoundationState object stores the propagating data for an ElasticFoundation
    object. One instance of this object is created internally by the ElasticFoundation
    object for each step. The instance is also deleted internally by the ElasticFoundation
    object.
    The ElasticFoundationState object has no constructor or methods.
    The ElasticFoundationState object is derived from the InteractionState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].steps[name].interactionStates[name]
    """

    #: A Float specifying the foundation stiffness per area.
    stiffness: float = None

    #: A SymbolicConstant specifying the propagation state of the stiffness member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    stiffnessState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None



from .Inertia import Inertia
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


class NonstructuralMass(Inertia):
    """The NonstructuralMass object defines the mass contribution from nonstructural features
    into the model.
    The NonstructuralMass object is derived from the Inertia object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import part
            mdb.models[name].parts[name].engineeringFeatures.inertias[name]
            import assembly
            mdb.models[name].rootAssembly.engineeringFeatures.inertias[name]

        The corresponding analysis keywords are:

        - NONSTRUCTURAL MASS
    """

    #: A Boolean specifying whether the inertia is suppressed or not. The default value is OFF.
    suppressed: Boolean = OFF

    #: A String specifying the repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the mass is applied.
    region: Region

    #: A SymbolicConstant specifying the units used to specify the nonstructural mass. Possible
    #: values are TOTAL_MASS, MASS_PER_VOLUME, MASS_PER_AREA, and MASS_PER_LENGTH.
    units: SymbolicConstant

    #: A Float specifying the mass magnitude.
    magnitude: float

    #: A SymbolicConstant specifying the distribution of the nonstructural mass. Possible
    #: values are MASS_PROPORTIONAL and VOLUME_PROPORTIONAL. The default value is
    #: MASS_PROPORTIONAL.The **distribution** argument applies only when **units** = TOTAL_MASS.
    distribution: SymbolicConstant = MASS_PROPORTIONAL

    def __init__(
        self,
        name: str,
        region: Region,
        units: SymbolicConstant,
        magnitude: float,
        distribution: SymbolicConstant = MASS_PROPORTIONAL,
    ):
        """This method creates a NonstructuralMass object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].parts[name].engineeringFeatures.NonstructuralMass
                mdb.models[name].rootAssembly.engineeringFeatures.NonstructuralMass

        Parameters
        ----------
        name
            A String specifying the repository key.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the mass is applied.
        units
            A SymbolicConstant specifying the units used to specify the nonstructural mass. Possible
            values are TOTAL_MASS, MASS_PER_VOLUME, MASS_PER_AREA, and MASS_PER_LENGTH.
        magnitude
            A Float specifying the mass magnitude.
        distribution
            A SymbolicConstant specifying the distribution of the nonstructural mass. Possible
            values are MASS_PROPORTIONAL and VOLUME_PROPORTIONAL. The default value is
            MASS_PROPORTIONAL.The **distribution** argument applies only when **units** = TOTAL_MASS.

        Returns
        -------
        NonstructuralMass
            A :py:class:`~abaqus.EngineeringFeature.NonstructuralMass.NonstructuralMass` object.
        """
        super().__init__()

    def setValues(self, distribution: SymbolicConstant = MASS_PROPORTIONAL):
        """This method modifies the NonstructuralMass object.

        Parameters
        ----------
        distribution
            A SymbolicConstant specifying the distribution of the nonstructural mass. Possible
            values are MASS_PROPORTIONAL and VOLUME_PROPORTIONAL. The default value is
            MASS_PROPORTIONAL.The **distribution** argument applies only when **units** = TOTAL_MASS.
        """
        ...



from .RayleighDampingByFrequencyComponentArray import (
    RayleighDampingByFrequencyComponentArray,
)


class RayleighDampingByFrequency:
    """A :py:class:`~abaqus.StepMiscellaneous.RayleighDampingByFrequency.RayleighDampingByFrequency` object contains Rayleigh Damping parameters.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name].rayleighDampingByFrequency
    """

    #: A :py:class:`~abaqus.StepMiscellaneous.RayleighDampingByFrequencyComponentArray.RayleighDampingByFrequencyComponentArray` object.
    components: RayleighDampingByFrequencyComponentArray = []
